@@ -1,22 +1,14 @@
-/* ---------------------------------------------------------------------
+/* -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010 - 2015 by the deal.II authors
- *                and Salvador Flores.
+ * SPDX-License-Identifier: LGPL-2.1-or-later
+ * Copyright (C) 2015 by Salvador Flores
  *
+ * This file is part of the deal.II code gallery.
  *
+ * -----------------------------------------------------------------------------
  *
- * This is free software; you can use it, redistribute
- * it, and/or modify it under the terms of the GNU Lesser General
- * Public License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) any later version.
- * The full text of the license can be found in the file LICENSE at
- * the top level of the deal.II distribution.
- *
- * ---------------------------------------------------------------------
- *
- * Author: Salvador Flores,
- *         Center for Mathematical Modelling,
- *       Universidad de Chile, 2015.
+ * Author: Salvador Flores, Center for Mathematical Modelling,
+ *         Universidad de Chile, 2015.
  */
 
 
@@ -281,8 +273,8 @@ namespace nsp
   ComputeMultiplier<dim>::get_names() const
   {
     std::vector<std::string> solution_names;
-    solution_names.push_back ("Gradient norm");
-    solution_names.push_back ("Lagrange multiplier");
+    solution_names.push_back ("Gradient_norm");
+    solution_names.push_back ("Lagrange_multiplier");
     return solution_names;
   }
 
@@ -508,7 +500,7 @@ namespace nsp
 
 
   /*************************************************************/
-// formating
+// formatting
 
   template <int dim>
   void ElastoplasticTorsion<dim>::format_convergence_tables()
@@ -632,7 +624,7 @@ namespace nsp
   }
 
   /***************************************************************************************/
-  /* the coeffcients W, W' and G defining the problem.
+  /* the coefficients W, W' and G defining the problem.
 
      Min_u \int W(|Du|^2) dx
 
@@ -786,9 +778,14 @@ namespace nsp
     solution_transfer.prepare_for_coarsening_and_refinement(present_solution);
     triangulation.execute_coarsening_and_refinement();
     dof_handler.distribute_dofs(fe);
+#  if DEAL_II_VERSION_GTE(9, 7, 0)
+    present_solution.reinit(dof_handler.n_dofs());
+    solution_transfer.interpolate(present_solution);
+#  else
     Vector<double> tmp(dof_handler.n_dofs());
     solution_transfer.interpolate(present_solution, tmp);
     present_solution = tmp;
+#  endif
     set_boundary_values ();
     hanging_node_constraints.clear();
 
@@ -1062,7 +1059,7 @@ namespace nsp
       }
     if (!done)
       {
-        std::cerr << ", max. no. of iterations reached wiht steplength= "<< alpha
+        std::cerr << ", max. no. of iterations reached with steplength= "<< alpha
                   << ", fcn value= "<< phi_alpha<<std::endl;
         return false;
       }
@@ -1214,7 +1211,7 @@ namespace nsp
     double ptime=0.0;
     timer.start ();
 
-    // initalize mesh for the selected domain
+    // initialize mesh for the selected domain
     init_mesh();
 
     // setup FE space
