@@ -1,25 +1,16 @@
-/* ---------------------------------------------------------------------
+/* -----------------------------------------------------------------------------
  *
- * Copyright (C) 2022 by the deal.II authors and Jake J. Harmon
+ * SPDX-License-Identifier: LGPL-2.1-or-later
+ * Copyright (C) 2022 by Jake J. Harmon
  *
- * This file is part of the deal.II library.
+ * This file is part of the deal.II code gallery.
  *
- * The deal.II library is free software; you can use it, redistribute
- * it, and/or modify it under the terms of the GNU Lesser General
- * Public License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) any later version.
- * The full text of the license can be found in the file LICENSE.md at
- * the top level directory of deal.II.
- *
- * ---------------------------------------------------------------------
-
+ * -----------------------------------------------------------------------------
  *
  * Author: Jake J. Harmon, 2022
- *
  */
 
 
-
 #include <deal.II/base/function_parser.h>
 #include <deal.II/base/index_set.h>
 #include <deal.II/base/parameter_handler.h>
@@ -33,6 +24,9 @@
 #include <deal.II/fe/fe_series.h>
 #include <deal.II/fe/fe_values.h>
 
+#if DEAL_II_VERSION_GTE(9, 7, 0)
+  #include <deal.II/grid/cell_data.h>
+#endif
 #include <deal.II/grid/tria.h>
 #include <deal.II/grid/tria_iterator.h>
 
@@ -1679,7 +1673,11 @@ namespace ErrorIndicators
     void
     prune_eigenpairs(const double &TOL);
 
+#if DEAL_II_VERSION_GTE(9, 6, 0)
+    std::vector<const ReadVector<PetscScalar> *>    eigenfunction_ptrs;
+#else
     std::vector<const PETScWrappers::MPI::Vector *> eigenfunction_ptrs;
+#endif
     std::vector<const double *>                     eigenvalue_ptrs;
 
     std::vector<std::shared_ptr<Vector<float>>> errors;
@@ -1810,11 +1808,21 @@ namespace ErrorIndicators
         estimated_error_per_cell[i] = errors[i].get();
       }
 
+#if DEAL_II_VERSION_GTE(9, 6, 0)
+    const auto solution_view = make_array_view(eigenfunction_ptrs);
+    auto error_view = make_array_view(estimated_error_per_cell);
+    KellyErrorEstimator<dim>::estimate(this->dof_handler,
+                                       *this->face_quadrature_collection,
+                                       {},
+                                       solution_view,
+                                       error_view);
+#else
     KellyErrorEstimator<dim>::estimate(this->dof_handler,
                                        *this->face_quadrature_collection,
                                        {},
                                        eigenfunction_ptrs,
                                        estimated_error_per_cell);
+#endif
 
     for (auto &error_vec : errors)
       {
