@@ -1,20 +1,12 @@
-/* ---------------------------------------------------------------------
- * Copyright (C) 2017 by the deal.II authors and
- *                           Jean-Paul Pelteret
+/* -----------------------------------------------------------------------------
  *
- * This file is part of the deal.II library.
+ * SPDX-License-Identifier: LGPL-2.1-or-later
+ * Copyright (C) 2017 by Jean-Paul Pelteret
  *
- * The deal.II library is free software; you can use it, redistribute
- * it, and/or modify it under the terms of the GNU Lesser General
- * Public License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) any later version.
- * The full text of the license can be found in the file LICENSE at
- * the top level of the deal.II distribution.
+ * This file is part of the deal.II code gallery.
+ *
+ * -----------------------------------------------------------------------------
  *
- * ---------------------------------------------------------------------
- */
-
-/*
  * Authors: Jean-Paul Pelteret, University of Erlangen-Nuremberg, 2017
  */
 
@@ -703,7 +695,7 @@ namespace ViscoElasStripHole
     mutable ConditionalOStream       pcout;
 
     Parameters::AllParameters parameters;
-    Triangulation<dim>        triangulation;
+    parallel::shared::Triangulation<dim> triangulation;
     Time                      time;
     mutable TimerOutput       timer;
     CellDataStorage<typename Triangulation<dim>::cell_iterator,
@@ -795,7 +787,7 @@ namespace ViscoElasStripHole
     this_mpi_process (Utilities::MPI::this_mpi_process(mpi_communicator)),
     pcout(std::cout, this_mpi_process == 0),
     parameters(input_file),
-    triangulation(Triangulation<dim>::maximum_smoothing),
+    triangulation(mpi_communicator, Triangulation<dim>::maximum_smoothing),
     time(parameters.end_time, parameters.delta_t),
     timer(mpi_communicator,
           pcout,
@@ -831,17 +823,10 @@ namespace ViscoElasStripHole
 
     make_grid();
     setup_system(solution_delta);
-    {
-      AffineConstraints<double> constraints;
-      constraints.close();
-      const ComponentSelectFunction<dim>
-      J_mask (J_component, n_components);
-      VectorTools::project (dof_handler,
-                            constraints,
-                            QGauss<dim>(degree+2),
-                            J_mask,
-                            solution_n);
-    }
+
+    // Set the J component to one, and all others to zero:
+    solution_n = 0;
+    solution_n.block(J_block) = 1.;
     output_results(time.get_timestep(), time.current());
     time.increment();
 
@@ -1299,7 +1284,7 @@ namespace ViscoElasStripHole
                                         tria_2d_not_flat);
 
     // Attach a manifold to the curved boundary and refine
-    // Note: We can only guarentee that the vertices sit on
+    // Note: We can only guarantee that the vertices sit on
     // the curve, so we must test with their position instead
     // of the cell centre.
     const Point<2> centre_2d (0,0);
@@ -1329,10 +1314,6 @@ namespace ViscoElasStripHole
     timer.enter_subsection("Setup system");
     pcout << "Setting up linear system..." << std::endl;
 
-    // Partition triangulation
-    GridTools::partition_triangulation (n_mpi_processes,
-                                        triangulation);
-
     block_component = std::vector<unsigned int> (n_components, u_block); // Displacement
     block_component[p_component] = p_block; // Pressure
     block_component[J_component] = J_block; // Dilatation
@@ -1591,7 +1572,7 @@ namespace ViscoElasStripHole
           }
       }
     Assert(vol_current > 0.0, ExcInternalError());
-    // Sum across all porcessors
+    // Sum across all processors
     dil_L2_error  = Utilities::MPI::sum(dil_L2_error,mpi_communicator);
     vol_reference = Utilities::MPI::sum(vol_reference,mpi_communicator);
     vol_current   = Utilities::MPI::sum(vol_current,mpi_communicator);
@@ -1851,6 +1832,13 @@ namespace ViscoElasStripHole
     if (it_nr > 1)
       return;
     constraints.clear();
+#if DEAL_II_VERSION_GTE(9, 6, 0)
+    constraints.reinit (locally_owned_dofs,
+                        locally_relevant_dofs);
+#else
+    constraints.reinit (locally_relevant_dofs);
+#endif
+    
     const bool apply_dirichlet_bc = (it_nr == 0);
     const FEValuesExtractors::Scalar x_displacement(0);
     const FEValuesExtractors::Scalar y_displacement(1);
