@@ -18,7 +18,6 @@ consists of the following files (click to inspect):
   (<a href="#ann-Functions.cc">annotated version</a>)
 - <a href="../code-gallery/Distributed_LDG_Method/LDGPoisson.cc">LDGPoisson.cc</a>
   (<a href="#ann-LDGPoisson.cc">annotated version</a>)
-- <a href="../code-gallery/Distributed_LDG_Method/doc/entry-name">doc/entry-name</a>
 - <a href="../code-gallery/Distributed_LDG_Method/image/poisson.png">image/poisson.png</a>
 
 <h1>Pictures from this code gallery program</h1>
@@ -56,7 +55,7 @@ I could not use this framework for solving my research problem and I
 needed to write the LDG method from scratch. I thought it 
 would be helpful for others to have access to 
 this example that goes through writing a discontinuous Galerkin method from 
-scatch and also shows how to do it in a distributed setting using the 
+scratch and also shows how to do it in a distributed setting using the 
 <a href="https://www.trilinos.org">Trilinos</a> library. This example may also
 be of interest to users that wish to use the LDG method, as the method is 
 distinctly different from the 
@@ -172,7 +171,7 @@ $\textbf{q}$:
 f(\textbf{x}) && \text{in} \ \Omega, \label{eq:Primary} \\
 \textbf{q}
 \; &= \;
- -\nabla u && \text{in} \ \Omega,  \label{eq:Auxillary} \\
+ -\nabla u && \text{in} \ \Omega,  \label{eq:Auxiliary} \\
 \textbf{q}  \cdot \textbf{n} 
 \; &= \; g_{N}(\textbf{x}) && \text{on} \ \partial \Omega_{N},\\
 u &= g_{D}(\textbf{x}) && \mbox{on}\ \partial \Omega_{D}.
@@ -310,7 +309,7 @@ parameter that is defined as,
 
 
 with $\tilde{\sigma}$ being a positive constant.  There are other choices of
-penalty values $\sigma$, but the one above produces in appoximations to solutions
+penalty values $\sigma$, but the one above produces in approximations to solutions
 that are the most accurate, see this 
 <a href="http://epubs.siam.org/doi/abs/10.1137/S0036142900371003">
 reference</a> for more info.
@@ -439,7 +438,21 @@ Equations: Theory and Implementation</a>
  * 
  * 
  * 
- * <a name="Functionscc"></a> 
+ * @code
+ *   /* -----------------------------------------------------------------------------
+ *    *
+ *    * SPDX-License-Identifier: LGPL-2.1-or-later
+ *    * Copyright (C) 2017 by Michael Harmon
+ *    *
+ *    * This file is part of the deal.II code gallery.
+ *    *
+ *    * -----------------------------------------------------------------------------
+ *    */
+ *   
+ * @endcode
+ * 
+ * 
+ * <a name="Functions.cc-Functionscc"></a> 
  * <h3>Functions.cc</h3>
  * In this file we keep right hand side function, Dirichlet boundary
  * conditions and solution to our Poisson equation problem.  Since
@@ -484,7 +497,7 @@ Equations: Theory and Implementation</a>
  *     {}
  *   
  *     virtual void vector_value(const Point<dim> &p,
- *                               Vector<double> &valuess) const override;
+ *                               Vector<double> &values) const override;
  *   };
  *   
  *   template <int dim>
@@ -537,7 +550,21 @@ Equations: Theory and Implementation</a>
  * 
  * 
  * 
- * <a name="LDGPoissoncc"></a> 
+ * @code
+ *   /* -----------------------------------------------------------------------------
+ *    *
+ *    * SPDX-License-Identifier: LGPL-2.1-or-later
+ *    * Copyright (C) 2017 by Michael Harmon
+ *    *
+ *    * This file is part of the deal.II code gallery.
+ *    *
+ *    * -----------------------------------------------------------------------------
+ *    */
+ *   
+ * @endcode
+ * 
+ * 
+ * <a name="LDGPoisson.cc-LDGPoissoncc"></a> 
  * <h3>LDGPoisson.cc</h3>
  * The code begins as per usual with a long list of the the included
  * files from the deal.ii library.
@@ -618,7 +645,7 @@ Equations: Theory and Implementation</a>
  *   
  * @endcode
  * 
- * The functions class contains all the defintions of the functions we
+ * The functions class contains all the definitions of the functions we
  * will use, i.e. the right hand side function, the boundary conditions
  * and the test functions.
  * 
@@ -633,7 +660,7 @@ Equations: Theory and Implementation</a>
  * Here is the main class for the Local Discontinuous Galerkin method
  * applied to Poisson's equation, we won't explain much of the
  * the class and method declarations, but dive deeper into describing the
- * functions when they are defined.  The only thing I will menion
+ * functions when they are defined.  The only thing I will mention
  * about the class declaration is that this is where I labeled
  * the different types of boundaries using enums.
  * 
@@ -730,11 +757,11 @@ Equations: Theory and Implementation</a>
  * @endcode
  * 
  * 
- * <a name="Classconstructoranddestructor"></a> 
+ * <a name="LDGPoisson.cc-Classconstructoranddestructor"></a> 
  * <h4>Class constructor and destructor</h4>
  * The constructor and destructor for this class is very much like the
  * like those for step-40.  The difference being that we'll be passing
- * in an integer, <code>degree</code>, which tells us the maxiumum order
+ * in an integer, <code>degree</code>, which tells us the maximum order
  * of the polynomial to use as well as <code>n_refine</code> which is the
  * global number of times we refine our mesh.  The other main differences
  * are that we use a FESystem object for our choice of basis
@@ -751,7 +778,7 @@ Equations: Theory and Implementation</a>
  * 
 
  * 
- * which tells us that the basis functions contain discontinous polynomials
+ * which tells us that the basis functions contain discontinuous polynomials
  * of order <code>degree</code> in each of the <code>dim</code> dimensions
  * for the vector field.  For the scalar unknown we
  * use a discontinuous polynomial of the order <code>degree</code>.
@@ -759,7 +786,7 @@ Equations: Theory and Implementation</a>
  * as well as its gradient, just like the mixed finite element method.
  * However, unlike the mixed method, the LDG method uses discontinuous
  * polynomials to approximate both variables.
- * The other difference bewteen our constructor and that of step-40 is that
+ * The other difference between our constructor and that of step-40 is that
  * we all instantiate our linear solver in the constructor definition.
  * 
  * @code
@@ -800,7 +827,7 @@ Equations: Theory and Implementation</a>
  * @endcode
  * 
  * 
- * <a name="Make_grid"></a> 
+ * <a name="LDGPoisson.cc-Make_grid"></a> 
  * <h4>Make_grid</h4>
  * This function shows how to make a grid using local
  * refinement and also shows how to label the boundaries
@@ -831,7 +858,7 @@ Equations: Theory and Implementation</a>
  * the domain.  This was just to show that
  * the LDG method is working with local
  * refinement and discussions on building
- * more realistic refinement stategies are
+ * more realistic refinement strategies are
  * discussed elsewhere in the deal.ii
  * documentation.
  * 
@@ -860,7 +887,7 @@ Equations: Theory and Implementation</a>
  * type, i.e. Dirichlet or Neumann,
  * we loop over all the cells in the mesh and then over
  * all the faces of each cell.  We then have to figure out
- * which faces are on the bounadry and set all faces
+ * which faces are on the boundary and set all faces
  * on the boundary to have
  * <code>boundary_id</code> to be <code>Dirichlet</code>.
  * We remark that one could easily set more complicated
@@ -886,7 +913,7 @@ Equations: Theory and Implementation</a>
  * @endcode
  * 
  * 
- * <a name="make_dofs"></a> 
+ * <a name="LDGPoisson.cc-make_dofs"></a> 
  * <h3>make_dofs</h3>
  * This function is responsible for distributing the degrees of
  * freedom (dofs) to the processors and allocating memory for
@@ -920,7 +947,7 @@ Equations: Theory and Implementation</a>
  *   
  * @endcode
  * 
- * We now renumber the dofs so that the vector of unkonwn dofs
+ * We now renumber the dofs so that the vector of unknown dofs
  * that we are solving for, <code>locally_relevant_solution</code>,
  * corresponds to a vector of the form,
  *   
@@ -938,19 +965,18 @@ Equations: Theory and Implementation</a>
  * matrix and vectors that we will write to.
  * 
  * @code
- *     IndexSet locally_owned_dofs = dof_handler.locally_owned_dofs();
+ *     const IndexSet &locally_owned_dofs = dof_handler.locally_owned_dofs();
  *   
  * @endcode
  * 
- * In additon to the locally owned dofs, we also need the the locally
+ * In addition to the locally owned dofs, we also need the the locally
  * relevant dofs.  These are the dofs that have read access to and we
  * need in order to do computations on our processor, but, that
  * we do not have the ability to write to.
  * 
  * @code
- *     IndexSet locally_relevant_dofs;
- *     DoFTools::extract_locally_relevant_dofs(dof_handler,
- *                                             locally_relevant_dofs);
+ *     const IndexSet locally_relevant_dofs =
+ *       DoFTools::extract_locally_relevant_dofs(dof_handler);
  *   
  *     const std::vector<types::global_dof_index> dofs_per_component =
  *       DoFTools::count_dofs_per_fe_component(dof_handler);
@@ -975,7 +1001,7 @@ Equations: Theory and Implementation</a>
  * 
  * Just like step-40 we create a dynamic sparsity pattern
  * and distribute it to the processors.  Notice how we do not have to
- * explictly mention that we are using a FESystem for system of
+ * explicitly mention that we are using a FESystem for system of
  * variables instead of a FE_DGQ for a scalar variable
  * or that we are using a discributed DoFHandler.  All these specifics
  * are taken care of under the hood by the deal.ii library.
@@ -985,7 +1011,7 @@ Equations: Theory and Implementation</a>
  * fluxes in the sparsity pattern.
  * 
  * @code
- *     DynamicSparsityPattern dsp(dof_handler.n_dofs());
+ *     DynamicSparsityPattern dsp(locally_relevant_dofs);
  *     DoFTools::make_flux_sparsity_pattern(dof_handler,
  *                                          dsp);
  *   
@@ -1052,7 +1078,7 @@ Equations: Theory and Implementation</a>
  * @endcode
  * 
  * 
- * <a name="assemble_system"></a> 
+ * <a name="LDGPoisson.cc-assemble_system"></a> 
  * <h4>assemble_system</h4>
  * This is the function that will assemble the global system matrix and
  * global right hand side vector for the LDG method. It starts out
@@ -1096,7 +1122,7 @@ Equations: Theory and Implementation</a>
  * for evaluating the basis functions
  * on one side of an element face as well as another FEFaceValues object,
  * <code>fe_neighbor_face_values</code>, for evaluating the basis functions
- * on the opposite side of the face, i.e. on the neighoring element's face.
+ * on the opposite side of the face, i.e. on the neighboring element's face.
  * In addition, we also introduce a FESubfaceValues object,
  * <code>fe_subface_values</code>, that
  * will be used for dealing with faces that have multiple refinement
@@ -1144,7 +1170,7 @@ Equations: Theory and Implementation</a>
  * 
  * As explained in the section on the LDG method we take our test
  * function to be v and multiply it on the left side of our differential
- * equation that is on u and peform integration by parts as explained in the
+ * equation that is on u and perform integration by parts as explained in the
  * introduction. Using this notation for test and solution function,
  * the matrices below will then stand for:
  *   
@@ -1452,7 +1478,7 @@ Equations: Theory and Implementation</a>
  * At this point we know that this cell and the neighbor
  * of this cell are on the same refinement level and
  * the work to assemble the interior flux matrices
- * is very much the same as before. Infact it is
+ * is very much the same as before. In fact it is
  * much simpler since we do not have to loop through the
  * subfaces.  However, we have to check that we do
  * not compute the same contribution twice. This would
@@ -1537,7 +1563,7 @@ Equations: Theory and Implementation</a>
  * @endcode
  * 
  * Now that have looped over all the faces for this
- * cell and computed as well as disributed the local
+ * cell and computed as well as distributed the local
  * flux matrices to the <code>system_matrix</code>, we
  * can finally distribute the cell's <code>local_matrix</code>
  * and <code>local_vector</code> contribution to the
@@ -1549,7 +1575,7 @@ Equations: Theory and Implementation</a>
  * the faces on the boundary of the domain contribute
  * to the <code>local_matrix</code>
  * and <code>system_rhs</code>.  We could distribute
- * the local contributions for each component seperately,
+ * the local contributions for each component separately,
  * but writing to the distributed sparse matrix and vector
  * is expensive and want to to minimize the number of times
  * we do so.
@@ -1583,7 +1609,7 @@ Equations: Theory and Implementation</a>
  * @endcode
  * 
  * 
- * <a name="assemble_cell_terms"></a> 
+ * <a name="LDGPoisson.cc-assemble_cell_terms"></a> 
  * <h4>assemble_cell_terms</h4>
  * This function deals with constructing the local matrix due to
  * the solid integrals over each element and is very similar to the
@@ -1677,12 +1703,12 @@ Equations: Theory and Implementation</a>
  * @endcode
  * 
  * 
- * <a name="assemble_Dirichlet_boundary_terms"></a> 
+ * <a name="LDGPoisson.cc-assemble_Dirichlet_boundary_terms"></a> 
  * <h4>assemble_Dirichlet_boundary_terms</h4>
  * Here we have the function that builds the <code>local_matrix</code>
  * contribution
  * and local right hand side vector, <code>local_vector</code>
- * for the Dirichlet boundary condtions.
+ * for the Dirichlet boundary conditions.
  * 
  * @code
  *   template<int dim>
@@ -1773,10 +1799,10 @@ Equations: Theory and Implementation</a>
  * @endcode
  * 
  * 
- * <a name="assemble_Neumann_boundary_terms"></a> 
+ * <a name="LDGPoisson.cc-assemble_Neumann_boundary_terms"></a> 
  * <h4>assemble_Neumann_boundary_terms</h4>
  * Here we have the function that builds the <code>local_matrix</code>
- * and <code>local_vector</code> for the Neumann boundary condtions.
+ * and <code>local_vector</code> for the Neumann boundary conditions.
  * 
  * @code
  *   template<int dim>
@@ -1836,7 +1862,7 @@ Equations: Theory and Implementation</a>
  * @endcode
  * 
  * We also compute the contribution for the flux for
- * $\widehat{q}$ on the Neumann bounary which is the
+ * $\widehat{q}$ on the Neumann boundary which is the
  * Neumann boundary condition and enters the right
  * hand side vector as
  *           
@@ -1855,7 +1881,7 @@ Equations: Theory and Implementation</a>
  * @endcode
  * 
  * 
- * <a name="assemble_flux_terms"></a> 
+ * <a name="LDGPoisson.cc-assemble_flux_terms"></a> 
  * <h4>assemble_flux_terms</h4>
  * Now we finally get to the function which builds the interior fluxes.
  * This is a rather long function
@@ -2119,7 +2145,7 @@ Equations: Theory and Implementation</a>
  * @endcode
  * 
  * 
- * <a name="distribute_local_flux_to_global"></a> 
+ * <a name="LDGPoisson.cc-distribute_local_flux_to_global"></a> 
  * <h4>distribute_local_flux_to_global</h4>
  * In this function we use the ConstraintMatrix to distribute
  * the local flux matrices to the global system matrix.
@@ -2184,22 +2210,22 @@ Equations: Theory and Implementation</a>
  * @endcode
  * 
  * 
- * <a name="solve"></a> 
+ * <a name="LDGPoisson.cc-solve"></a> 
  * <h4>solve</h4>
  * As mentioned earlier I used a direct solver to solve
  * the linear system of equations resulting from the LDG
  * method applied to the Poisson equation. One could also
- * use a iterative sovler, however, we then need to use
- * a preconditoner and that was something I did not wanted
+ * use a iterative solver, however, we then need to use
+ * a preconditioner and that was something I did not wanted
  * to get into. For information on preconditioners
  * for the LDG Method see this
  * <a href="http://epubs.siam.org/doi/abs/10.1137/S1064827502410657">
- * paper</a>. The uses of a direct sovler here is
+ * paper</a>. The uses of a direct solver here is
  * somewhat of a limitation.  The built-in distributed
  * direct solver in Trilinos reduces everything to one
  * processor, solves the system and then distributes
  * everything back out to the other processors.  However,
- * by linking to more advanced direct sovlers through
+ * by linking to more advanced direct solvers through
  * Trilinos one can accomplish fully distributed computations
  * and not much about the following function calls will
  * change.
@@ -2228,7 +2254,7 @@ Equations: Theory and Implementation</a>
  *   
  * @endcode
  * 
- * Now we can preform the solve on the completeley distributed
+ * Now we can perform the solve on the completeley distributed
  * right hand side vector, system matrix and the completely
  * distributed solution.
  * 
@@ -2263,13 +2289,13 @@ Equations: Theory and Implementation</a>
  * @endcode
  * 
  * 
- * <a name="output_results"></a> 
+ * <a name="LDGPoisson.cc-output_results"></a> 
  * <h4>output_results</h4>
- * This function deals with the writing of the reuslts in parallel
+ * This function deals with the writing of the results in parallel
  * to disk.  It is almost exactly the same as
- * in step-40 and we wont go into it.  It is noteworthy
+ * in step-40 and we won't go into it.  It is noteworthy
  * that in step-40 the output is only the scalar solution,
- * while in our situation, we are outputing both the scalar
+ * while in our situation, we are outputting both the scalar
  * solution as well as the vector field solution. The only
  * difference between this function and the one in step-40
  * is in the <code>solution_names</code> vector where we have to add
@@ -2348,7 +2374,7 @@ Equations: Theory and Implementation</a>
  * @endcode
  * 
  * 
- * <a name="run"></a> 
+ * <a name="LDGPoisson.cc-run"></a> 
  * <h4>run</h4>
  * The only public function of this class is pretty much exactly
  * the same as all the other deal.ii examples except I setting
@@ -2372,7 +2398,7 @@ Equations: Theory and Implementation</a>
  * @endcode
  * 
  * 
- * <a name="main"></a> 
+ * <a name="LDGPoisson.cc-main"></a> 
  * <h3>main</h3>
  * Here it the main class of our program, since it is nearly exactly
  * the same as step-40 and many of the other examples I won't
