@@ -18,7 +18,6 @@ consists of the following files (click to inspect):
   (<a href="#ann-Distributed_Moving_Laser_Heating.cc">annotated version</a>)
 - <a href="../code-gallery/Distributed_Moving_Laser_Heating/boundaryInit.h">boundaryInit.h</a>
   (<a href="#ann-boundaryInit.h">annotated version</a>)
-- <a href="../code-gallery/Distributed_Moving_Laser_Heating/doc/entry-name">doc/entry-name</a>
 - <a href="../code-gallery/Distributed_Moving_Laser_Heating/docs_old/builds-on">docs_old/builds-on</a>
 - <a href="../code-gallery/Distributed_Moving_Laser_Heating/docs_old/intro.dox">docs_old/intro.dox</a>
 - <a href="../code-gallery/Distributed_Moving_Laser_Heating/docs_old/kind">docs_old/kind</a>
@@ -63,7 +62,7 @@ consists of the following files (click to inspect):
 <h1>Annotated version of README.md</h1>
 
 # Introduction
-In this tutorial, the studied problem is to simulate temperature distributions of a sample under a moving laser. Light penetrates the substrate without loss. The top-covered thin-film is, however, a light absorbing material. For simplicity, the thin-film is assumed to be TiO$_2$ mixed with silver nanoparticles, which supports light heating of the material by absorbing light energy. For this tutorial, we only consider the isotropic absorption. Figure \ref{fgr:s1} illustrates the sketch of the problem. The absorption coefficient is assumed to be $10^4 m^{-1}$. The substrate is glass. The thickness of the thin-film is assumed to be 400 nm. The spot size at the top of thin film is $20 \mu m$ at $e^{-2}$. The writing speed is assumed to be 10 mm/s. The laser power is 0.4 W. The time step is set as 10 $\mu s$. The initial position of laser center is $-50 \mu m$ with 50 $\mu m$ distance away from the left boundary to avoid boundary effects.
+In this tutorial, the studied problem is to simulate temperature distributions of a sample under a moving laser. Light penetrates the substrate without loss. The top-covered thin-film is, however, a light absorbing material. For simplicity, the thin-film is assumed to be TiO$_2$ mixed with silver nanoparticles, which supports light heating of the material by absorbing light energy. For this tutorial, we only consider the isotropic absorption. The Figure below illustrates the sketch of the problem. The absorption coefficient is assumed to be $10^4 m^{-1}$. The substrate is glass. The thickness of the thin-film is assumed to be 400 nm. The spot size at the top of thin film is $20 \mu m$ at $e^{-2}$. The writing speed is assumed to be 10 mm/s. The laser power is 0.4 W. The time step is set as 10 $\mu s$. The initial position of laser center is $-50 \mu m$ with 50 $\mu m$ distance away from the left boundary to avoid boundary effects.
 
 ## Illustration of the problem
 
@@ -96,7 +95,7 @@ since the test function is time invariant (because the grid is not changed), we
     \int T T^{'}_{i} dV &= u_{i}
 @f}
 
-\noindent let 
+Let 
 @f{align*}
     M &= \int \rho C_m T^{'_i} T^{'_j} dV  \\
     A & = \int k \nabla T^{'_i} \cdot \nabla T^{'_j} dV \\
@@ -198,8 +197,7 @@ The colors stand for different cores.
 ![threads](../code-gallery/Distributed_Moving_Laser_Heating/images/threads-2d.png)
 
 # References
-<code>
-	
+@code{.sh}	
 @article{ma2021numerical,
   title={Numerical study of laser micro-and nano-processing of nanocomposite porous materials},
   author={Ma, Hongfeng},
@@ -242,8 +240,7 @@ The colors stand for different cores.
   year={1947},
   organization={Cambridge University Press}
 }
-
-</code>
+@endcode
 
 
 <a name="ann-Distributed_Moving_Laser_Heating.cc"></a>
@@ -253,20 +250,15 @@ The colors stand for different cores.
  * 
  * 
  * @code
- *   /* ---------------------------------------------------------------------
+ *   /* -----------------------------------------------------------------------------
  *    *
- *    * Copyright (C) 2021 by the deal.II authors
+ *    * SPDX-License-Identifier: LGPL-2.1-or-later
+ *    * Copyright (C) 2021 by Hongfeng Ma
+ *    * Copyright (C) 2021 by Tatiana E. Itina
  *    *
- *    * This file is part of the deal.II library.
+ *    * This file is part of the deal.II code gallery.
  *    *
- *    * The deal.II library is free software; you can use it, redistribute
- *    * it, and/or modify it under the terms of the GNU Lesser General
- *    * Public License as published by the Free Software Foundation; either
- *    * version 2.1 of the License, or (at your option) any later version.
- *    * The full text of the license can be found in the file LICENSE.md at
- *    * the top level directory of deal.II.
- *    *
- *    * ---------------------------------------------------------------------
+ *    * -----------------------------------------------------------------------------
  *    *
  *    * Authors: Hongfeng Ma, 2021.
  *    */
@@ -275,7 +267,7 @@ The colors stand for different cores.
  * @endcode
  * 
  * 
- * <a name="Includefiles"></a> 
+ * <a name="Distributed_Moving_Laser_Heating.cc-Includefiles"></a> 
  * <h3>Include files</h3>
  * 
 
@@ -496,7 +488,7 @@ The colors stand for different cores.
  * @endcode
  * 
  * 
- * <a name="LaserHeatingmake_grid"></a> 
+ * <a name="Distributed_Moving_Laser_Heating.cc-LaserHeatingmake_grid"></a> 
  * <h4>LaserHeating::make_grid</h4>
  * make grid by importing msh file, and rescale
  * 
@@ -523,7 +515,7 @@ The colors stand for different cores.
  * @endcode
  * 
  * 
- * <a name="LaserHeatingsetup_system"></a> 
+ * <a name="Distributed_Moving_Laser_Heating.cc-LaserHeatingsetup_system"></a> 
  * <h4>LaserHeating::setup_system</h4>
  * initialization
  * 
@@ -540,8 +532,8 @@ The colors stand for different cores.
  *               << dof_handler.n_dofs()
  *               << std::endl;
  *   
- *     locally_owned_dofs = dof_handler.locally_owned_dofs();
- *     DoFTools::extract_locally_relevant_dofs (dof_handler, locally_relevant_dofs);
+ *     locally_owned_dofs    = dof_handler.locally_owned_dofs();
+ *     locally_relevant_dofs = DoFTools::extract_locally_relevant_dofs (dof_handler);
  *   
  * @endcode
  * 
@@ -584,7 +576,7 @@ The colors stand for different cores.
  * @endcode
  * 
  * 
- * <a name="LaserHeatingassemble_system_matrix"></a> 
+ * <a name="Distributed_Moving_Laser_Heating.cc-LaserHeatingassemble_system_matrix"></a> 
  * <h4>LaserHeating::assemble_system_matrix</h4>
  * 
 
@@ -737,7 +729,7 @@ The colors stand for different cores.
  * @endcode
  * 
  * 
- * <a name="LaserHeatingdynamic_assemble_rhs_T"></a> 
+ * <a name="Distributed_Moving_Laser_Heating.cc-LaserHeatingdynamic_assemble_rhs_T"></a> 
  * <h4>LaserHeating::dynamic_assemble_rhs_T</h4>
  * The right hand side is assembled each time during running, which is necessary as
  * the laser source is moving. To separate the heat source and the right hand 
@@ -820,7 +812,7 @@ The colors stand for different cores.
  * @endcode
  * 
  * 
- * <a name="LaserHeatingsolve"></a> 
+ * <a name="Distributed_Moving_Laser_Heating.cc-LaserHeatingsolve"></a> 
  * <h4>LaserHeating::solve</h4>
  * Solving the equation is direct. Recall that we have defined several matrices and vectors,
  * to avoid ambiguous, here, we only use system_matrix_T as the system matrix, system_rhs_T
@@ -869,7 +861,7 @@ The colors stand for different cores.
  * @endcode
  * 
  * 
- * <a name="LaserHeatingrefine_mesh"></a> 
+ * <a name="Distributed_Moving_Laser_Heating.cc-LaserHeatingrefine_mesh"></a> 
  * <h4>LaserHeating::refine_mesh</h4>
  * 
 
@@ -919,7 +911,7 @@ The colors stand for different cores.
  * @endcode
  * 
  * 
- * <a name="LaserHeatinghoutput_results"></a> 
+ * <a name="Distributed_Moving_Laser_Heating.cc-LaserHeatinghoutput_results"></a> 
  * <h4>LaserHeatingh::output_results</h4>
  * 
 
@@ -988,7 +980,7 @@ The colors stand for different cores.
  * @endcode
  * 
  * 
- * <a name="LaserHeatingrun"></a> 
+ * <a name="Distributed_Moving_Laser_Heating.cc-LaserHeatingrun"></a> 
  * <h4>LaserHeating::run</h4>
  * 
 
@@ -1121,7 +1113,7 @@ The colors stand for different cores.
  * @endcode
  * 
  * 
- * <a name="Thecodemaincodefunction"></a> 
+ * <a name="Distributed_Moving_Laser_Heating.cc-Thecodemaincodefunction"></a> 
  * <h3>The <code>main</code> function</h3>
  * 
 
@@ -1178,7 +1170,19 @@ The colors stand for different cores.
  * 
  * 
  * 
-
+ * @code
+ *   /* -----------------------------------------------------------------------------
+ *    *
+ *    * SPDX-License-Identifier: LGPL-2.1-or-later
+ *    * Copyright (C) 2021 by Hongfeng Ma
+ *    * Copyright (C) 2021 by Tatiana E. Itina
+ *    *
+ *    * This file is part of the deal.II code gallery.
+ *    *
+ *    * -----------------------------------------------------------------------------
+ *    */
+ *   
+ * @endcode
  * 
  * #----------------------------------------------------------
  * #
@@ -1341,7 +1345,19 @@ The colors stand for different cores.
  * 
  * 
  * 
-
+ * @code
+ *   /* -----------------------------------------------------------------------------
+ *    *
+ *    * SPDX-License-Identifier: LGPL-2.1-or-later
+ *    * Copyright (C) 2021 by Hongfeng Ma
+ *    * Copyright (C) 2021 by Tatiana E. Itina
+ *    *
+ *    * This file is part of the deal.II code gallery.
+ *    *
+ *    * -----------------------------------------------------------------------------
+ *    */
+ *   
+ * @endcode
  * 
  * # physics constants
  * 
@@ -1403,6 +1419,21 @@ The colors stand for different cores.
  * 
  * 
  * 
+ * 
+ * @code
+ *   /* -----------------------------------------------------------------------------
+ *    *
+ *    * SPDX-License-Identifier: LGPL-2.1-or-later
+ *    * Copyright (C) 2021 by Hongfeng Ma
+ *    * Copyright (C) 2021 by Tatiana E. Itina
+ *    *
+ *    * This file is part of the deal.II code gallery.
+ *    *
+ *    * -----------------------------------------------------------------------------
+ *    */
+ *   
+ * @endcode
+ * 
  * #----------------------------------------------------------
  * #
  * # This file defines the boundary and initial conditions
