@@ -1,17 +1,12 @@
-/* ---------------------------------------------------------------------
+/* -----------------------------------------------------------------------------
  *
- * Copyright (C) 2021 by the deal.II authors
+ * SPDX-License-Identifier: LGPL-2.1-or-later
+ * Copyright (C) 2021 by Hongfeng Ma
+ * Copyright (C) 2021 by Tatiana E. Itina
  *
- * This file is part of the deal.II library.
+ * This file is part of the deal.II code gallery.
  *
- * The deal.II library is free software; you can use it, redistribute
- * it, and/or modify it under the terms of the GNU Lesser General
- * Public License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) any later version.
- * The full text of the license can be found in the file LICENSE.md at
- * the top level directory of deal.II.
- *
- * ---------------------------------------------------------------------
+ * -----------------------------------------------------------------------------
  *
  * Authors: Hongfeng Ma, 2021.
  */
@@ -207,8 +202,8 @@ void LaserHeating<dim>::setup_system ()
             << dof_handler.n_dofs()
             << std::endl;
 
-  locally_owned_dofs = dof_handler.locally_owned_dofs();
-  DoFTools::extract_locally_relevant_dofs (dof_handler, locally_relevant_dofs);
+  locally_owned_dofs    = dof_handler.locally_owned_dofs();
+  locally_relevant_dofs = DoFTools::extract_locally_relevant_dofs (dof_handler);
 
   // we want to output solution, so here should have ghost cells
   old_solution_T.reinit     (locally_owned_dofs,locally_relevant_dofs,mpi_communicator);
