@@ -16,7 +16,6 @@ consists of the following files (click to inspect):
 - <a href="../code-gallery/ElastoplasticTorsion/ElastoplasticTorsion.cc">ElastoplasticTorsion.cc</a>
   (<a href="#ann-ElastoplasticTorsion.cc">annotated version</a>)
 - <a href="../code-gallery/ElastoplasticTorsion/doc/ElastoplasticTorsion-doc.pdf">doc/ElastoplasticTorsion-doc.pdf</a>
-- <a href="../code-gallery/ElastoplasticTorsion/doc/entry-name">doc/entry-name</a>
 
 <a name="ann-ElastoplasticTorsion.cc"></a>
 <h1>Annotated version of ElastoplasticTorsion.cc</h1>
@@ -25,25 +24,17 @@ consists of the following files (click to inspect):
  * 
  * 
  * @code
- *   /* ---------------------------------------------------------------------
+ *   /* -----------------------------------------------------------------------------
  *    *
- *    * Copyright (C) 2010 - 2015 by the deal.II authors
- *    *                and Salvador Flores.
+ *    * SPDX-License-Identifier: LGPL-2.1-or-later
+ *    * Copyright (C) 2015 by Salvador Flores
  *    *
+ *    * This file is part of the deal.II code gallery.
  *    *
+ *    * -----------------------------------------------------------------------------
  *    *
- *    * This is free software; you can use it, redistribute
- *    * it, and/or modify it under the terms of the GNU Lesser General
- *    * Public License as published by the Free Software Foundation; either
- *    * version 2.1 of the License, or (at your option) any later version.
- *    * The full text of the license can be found in the file LICENSE at
- *    * the top level of the deal.II distribution.
- *    *
- *    * ---------------------------------------------------------------------
- *    *
- *    * Author: Salvador Flores,
- *    *         Center for Mathematical Modelling,
- *    *       Universidad de Chile, 2015.
+ *    * Author: Salvador Flores, Center for Mathematical Modelling,
+ *    *         Universidad de Chile, 2015.
  *    */
  *   
  *   
@@ -336,8 +327,8 @@ consists of the following files (click to inspect):
  *     ComputeMultiplier<dim>::get_names() const
  *     {
  *       std::vector<std::string> solution_names;
- *       solution_names.push_back ("Gradient norm");
- *       solution_names.push_back ("Lagrange multiplier");
+ *       solution_names.push_back ("Gradient_norm");
+ *       solution_names.push_back ("Lagrange_multiplier");
  *       return solution_names;
  *     }
  *   
@@ -615,7 +606,7 @@ consists of the following files (click to inspect):
  *     /*************************************************************/
  * @endcode
  * 
- * formating
+ * formatting
  * 
 
  * 
@@ -775,7 +766,7 @@ consists of the following files (click to inspect):
  *     }
  *   
  *     /***************************************************************************************/
- *     /* the coeffcients W, W' and G defining the problem.
+ *     /* the coefficients W, W' and G defining the problem.
  *   
  *        Min_u \int W(|Du|^2) dx
  *   
@@ -935,9 +926,14 @@ consists of the following files (click to inspect):
  *       solution_transfer.prepare_for_coarsening_and_refinement(present_solution);
  *       triangulation.execute_coarsening_and_refinement();
  *       dof_handler.distribute_dofs(fe);
+ *   #  if DEAL_II_VERSION_GTE(9, 7, 0)
+ *       present_solution.reinit(dof_handler.n_dofs());
+ *       solution_transfer.interpolate(present_solution);
+ *   #  else
  *       Vector<double> tmp(dof_handler.n_dofs());
  *       solution_transfer.interpolate(present_solution, tmp);
  *       present_solution = tmp;
+ *   #  endif
  *       set_boundary_values ();
  *       hanging_node_constraints.clear();
  *   
@@ -1265,7 +1261,7 @@ consists of the following files (click to inspect):
  *         }
  *       if (!done)
  *         {
- *           std::cerr << ", max. no. of iterations reached wiht steplength= "<< alpha
+ *           std::cerr << ", max. no. of iterations reached with steplength= "<< alpha
  *                     << ", fcn value= "<< phi_alpha<<std::endl;
  *           return false;
  *         }
@@ -1467,7 +1463,7 @@ consists of the following files (click to inspect):
  *   
  * @endcode
  * 
- * initalize mesh for the selected domain
+ * initialize mesh for the selected domain
  * 
  * @code
  *       init_mesh();
