@@ -16,7 +16,6 @@ consists of the following files (click to inspect):
 - <a href="../code-gallery/Linear_Elastic_Active_Skeletal_Muscle_Model/CMakeLists.txt">CMakeLists.txt</a>
 - <a href="../code-gallery/Linear_Elastic_Active_Skeletal_Muscle_Model/Linear_active_muscle_model.cc">Linear_active_muscle_model.cc</a>
   (<a href="#ann-Linear_active_muscle_model.cc">annotated version</a>)
-- <a href="../code-gallery/Linear_Elastic_Active_Skeletal_Muscle_Model/doc/entry-name">doc/entry-name</a>
 - <a href="../code-gallery/Linear_Elastic_Active_Skeletal_Muscle_Model/doc/geometry/biceps-geometry.png">doc/geometry/biceps-geometry.png</a>
 - <a href="../code-gallery/Linear_Elastic_Active_Skeletal_Muscle_Model/doc/geometry/geometry.png">doc/geometry/geometry.png</a>
 - <a href="../code-gallery/Linear_Elastic_Active_Skeletal_Muscle_Model/doc/geometry/geometry.tex">doc/geometry/geometry.tex</a>
@@ -118,7 +117,7 @@ a diameter of `80mm` at its mid-point.
 We assume that there exists a single muscle fibre family orientated axially.
 The orientation of the underlying muscle fibres is, however, not parallel,
 but rather follows the curvature of the macroscopic anatomy.
-The longitudinal profile of the muscle is generated using a trignometric
+The longitudinal profile of the muscle is generated using a trigonometric
 function, as opposed to being extracted from medical images.
 The benefit to doing so is that the geometry can be (parametrically) created
 in `deal.II` itself and the associated microstructural orientation can be
@@ -251,23 +250,16 @@ similar to that demonstrated before.
  * 
  * 
  * @code
- *   /* ---------------------------------------------------------------------
- *    * Copyright (C) 2017 by the deal.II authors and
- *    *                           Jean-Paul Pelteret and Tim Hamann
+ *   /* -----------------------------------------------------------------------------
  *    *
- *    * This file is part of the deal.II library.
+ *    * SPDX-License-Identifier: LGPL-2.1-or-later
+ *    * Copyright (C) 2017 by Jean-Paul Pelteret
+ *    * Copyright (C) 2017 by Tim Hamann
  *    *
- *    * The deal.II library is free software; you can use it, redistribute
- *    * it, and/or modify it under the terms of the GNU Lesser General
- *    * Public License as published by the Free Software Foundation; either
- *    * version 2.1 of the License, or (at your option) any later version.
- *    * The full text of the license can be found in the file LICENSE at
- *    * the top level of the deal.II distribution.
+ *    * This file is part of the deal.II code gallery.
+ *    *
+ *    * -----------------------------------------------------------------------------
  *    *
- *    * ---------------------------------------------------------------------
- *    */
- *   
- *   /*
  *    * Authors: Jean-Paul Pelteret, Tim Hamann,
  *    *          University of Erlangen-Nuremberg, 2017
  *    *
@@ -279,7 +271,7 @@ similar to that demonstrated before.
  * @endcode
  * 
  * 
- * <a name="Includefiles"></a> 
+ * <a name="Linear_active_muscle_model.cc-Includefiles"></a> 
  * <h3>Include files</h3>
  * 
 
@@ -327,7 +319,7 @@ similar to that demonstrated before.
  * @endcode
  * 
  * 
- * <a name="Runtimeparameters"></a> 
+ * <a name="Linear_active_muscle_model.cc-Runtimeparameters"></a> 
  * <h3>Run-time parameters</h3>
  * 
 
@@ -341,7 +333,7 @@ similar to that demonstrated before.
  * @endcode
  * 
  * 
- * <a name="FiniteElementsystem"></a> 
+ * <a name="Linear_active_muscle_model.cc-FiniteElementsystem"></a> 
  * <h4>Finite Element system</h4>
  * 
 
@@ -390,7 +382,7 @@ similar to that demonstrated before.
  * @endcode
  * 
  * 
- * <a name="Problem"></a> 
+ * <a name="Linear_active_muscle_model.cc-Problem"></a> 
  * <h4>Problem</h4>
  * 
 
@@ -432,7 +424,7 @@ similar to that demonstrated before.
  * @endcode
  * 
  * 
- * <a name="IsotonicContractionGeometry"></a> 
+ * <a name="Linear_active_muscle_model.cc-IsotonicContractionGeometry"></a> 
  * <h4>IsotonicContractionGeometry</h4>
  * 
 
@@ -473,7 +465,7 @@ similar to that demonstrated before.
  * @endcode
  * 
  * 
- * <a name="BicepsBrachiiGeometry"></a> 
+ * <a name="Linear_active_muscle_model.cc-BicepsBrachiiGeometry"></a> 
  * <h4>BicepsBrachiiGeometry</h4>
  * 
 
@@ -569,7 +561,7 @@ similar to that demonstrated before.
  * @endcode
  * 
  * 
- * <a name="Neurologicalsignal"></a> 
+ * <a name="Linear_active_muscle_model.cc-Neurologicalsignal"></a> 
  * <h4>Neurological signal</h4>
  * 
 
@@ -619,7 +611,7 @@ similar to that demonstrated before.
  * @endcode
  * 
  * 
- * <a name="Time"></a> 
+ * <a name="Linear_active_muscle_model.cc-Time"></a> 
  * <h4>Time</h4>
  * 
 
@@ -673,7 +665,7 @@ similar to that demonstrated before.
  * @endcode
  * 
  * 
- * <a name="Allparameters"></a> 
+ * <a name="Linear_active_muscle_model.cc-Allparameters"></a> 
  * <h4>All parameters</h4>
  * 
 
@@ -746,7 +738,7 @@ similar to that demonstrated before.
  * @endcode
  * 
  * 
- * <a name="Bodyforcevalues"></a> 
+ * <a name="Linear_active_muscle_model.cc-Bodyforcevalues"></a> 
  * <h3>Body force values</h3>
  * 
 
@@ -879,7 +871,7 @@ similar to that demonstrated before.
  * @endcode
  * 
  * 
- * <a name="Utilityfunctions"></a> 
+ * <a name="Linear_active_muscle_model.cc-Utilityfunctions"></a> 
  * <h3>Utility functions</h3>
  * 
 
@@ -918,7 +910,7 @@ similar to that demonstrated before.
  * @endcode
  * 
  * 
- * <a name="Propertiesformusclematrix"></a> 
+ * <a name="Linear_active_muscle_model.cc-Propertiesformusclematrix"></a> 
  * <h3>Properties for muscle matrix</h3>
  * 
 
@@ -942,7 +934,7 @@ similar to that demonstrated before.
  * @endcode
  * 
  * 
- * <a name="Localdataformusclefibres"></a> 
+ * <a name="Linear_active_muscle_model.cc-Localdataformusclefibres"></a> 
  * <h3>Local data for muscle fibres</h3>
  * 
 
@@ -1144,7 +1136,7 @@ similar to that demonstrated before.
  * 
  * Values from previous state
  * These were the values that were used in the assembly,
- * so we must use them in the update step to be consistant.
+ * so we must use them in the update step to be consistent.
  * Need to compute these before we overwrite epsilon_c_t1
  * 
  * @code
@@ -1168,7 +1160,7 @@ similar to that demonstrated before.
  * @endcode
  * 
  * 
- * <a name="ThecodeLinearMuscleModelProblemcodeclasstemplate"></a> 
+ * <a name="Linear_active_muscle_model.cc-ThecodeLinearMuscleModelProblemcodeclasstemplate"></a> 
  * <h3>The <code>LinearMuscleModelProblem</code> class template</h3>
  * 
 
@@ -1251,7 +1243,7 @@ similar to that demonstrated before.
  * @endcode
  * 
  * 
- * <a name="LinearMuscleModelProblemLinearMuscleModelProblem"></a> 
+ * <a name="Linear_active_muscle_model.cc-LinearMuscleModelProblemLinearMuscleModelProblem"></a> 
  * <h4>LinearMuscleModelProblem::LinearMuscleModelProblem</h4>
  * 
 
@@ -1285,7 +1277,7 @@ similar to that demonstrated before.
  * @endcode
  * 
  * 
- * <a name="LinearMuscleModelProblemLinearMuscleModelProblem"></a> 
+ * <a name="Linear_active_muscle_model.cc-LinearMuscleModelProblemLinearMuscleModelProblem"></a> 
  * <h4>LinearMuscleModelProblem::~LinearMuscleModelProblem</h4>
  * 
 
@@ -1302,7 +1294,7 @@ similar to that demonstrated before.
  * @endcode
  * 
  * 
- * <a name="LinearMuscleModelProblemmake_grid"></a> 
+ * <a name="Linear_active_muscle_model.cc-LinearMuscleModelProblemmake_grid"></a> 
  * <h4>LinearMuscleModelProblem::make_grid</h4>
  * 
 
@@ -1350,7 +1342,7 @@ similar to that demonstrated before.
  * Provides the muscle direction at the point @p pt
  * in the real geometry (one that has undergone the
  * transformation given by the profile() function)
- * and subequent grid rescaling.
+ * and subsequent grid rescaling.
  * The directions are given by the gradient of the
  * transformation function (i.e. the fibres are
  * orientated by the curvature of the muscle).
@@ -1550,7 +1542,7 @@ similar to that demonstrated before.
  * @endcode
  * 
  * 
- * <a name="LinearMuscleModelProblemsetup_muscle_fibres"></a> 
+ * <a name="Linear_active_muscle_model.cc-LinearMuscleModelProblemsetup_muscle_fibres"></a> 
  * <h4>LinearMuscleModelProblem::setup_muscle_fibres</h4>
  * 
 
@@ -1609,7 +1601,7 @@ similar to that demonstrated before.
  * @endcode
  * 
  * 
- * <a name="LinearMuscleModelProblemupdate_fibre_state"></a> 
+ * <a name="Linear_active_muscle_model.cc-LinearMuscleModelProblemupdate_fibre_state"></a> 
  * <h4>LinearMuscleModelProblem::update_fibre_state</h4>
  * 
 
@@ -1684,7 +1676,7 @@ similar to that demonstrated before.
  * @endcode
  * 
  * 
- * <a name="LinearMuscleModelProblemsetup_system"></a> 
+ * <a name="Linear_active_muscle_model.cc-LinearMuscleModelProblemsetup_system"></a> 
  * <h4>LinearMuscleModelProblem::setup_system</h4>
  * 
 
@@ -1725,7 +1717,7 @@ similar to that demonstrated before.
  * @endcode
  * 
  * 
- * <a name="LinearMuscleModelProblemassemble_system"></a> 
+ * <a name="Linear_active_muscle_model.cc-LinearMuscleModelProblemassemble_system"></a> 
  * <h4>LinearMuscleModelProblem::assemble_system</h4>
  * 
 
@@ -1821,7 +1813,7 @@ similar to that demonstrated before.
  * @endcode
  * 
  * 
- * <a name="LinearMuscleModelProblemassemble_system"></a> 
+ * <a name="Linear_active_muscle_model.cc-LinearMuscleModelProblemassemble_system"></a> 
  * <h4>LinearMuscleModelProblem::assemble_system</h4>
  * 
 
@@ -2227,7 +2219,7 @@ similar to that demonstrated before.
  * @endcode
  * 
  * 
- * <a name="LinearMuscleModelProblemsolve"></a> 
+ * <a name="Linear_active_muscle_model.cc-LinearMuscleModelProblemsolve"></a> 
  * <h4>LinearMuscleModelProblem::solve</h4>
  * 
 
@@ -2253,7 +2245,7 @@ similar to that demonstrated before.
  * @endcode
  * 
  * 
- * <a name="LinearMuscleModelProblemoutput_results"></a> 
+ * <a name="Linear_active_muscle_model.cc-LinearMuscleModelProblemoutput_results"></a> 
  * <h4>LinearMuscleModelProblem::output_results</h4>
  * 
 
@@ -2551,7 +2543,7 @@ similar to that demonstrated before.
  * @endcode
  * 
  * 
- * <a name="LinearMuscleModelProblemrun"></a> 
+ * <a name="Linear_active_muscle_model.cc-LinearMuscleModelProblemrun"></a> 
  * <h4>LinearMuscleModelProblem::run</h4>
  * 
 
@@ -2631,7 +2623,7 @@ similar to that demonstrated before.
  * @endcode
  * 
  * 
- * <a name="Thecodemaincodefunction"></a> 
+ * <a name="Linear_active_muscle_model.cc-Thecodemaincodefunction"></a> 
  * <h3>The <code>main</code> function</h3>
  * 
 
