@@ -32,7 +32,6 @@ consists of the following files (click to inspect):
   (<a href="#ann-Matlab/precomputations.m">annotated version</a>)
 - <a href="../code-gallery/MCMC-Laplace/Python/forward_solver.py">Python/forward_solver.py</a>
   (<a href="#ann-Python/forward_solver.py">annotated version</a>)
-- <a href="../code-gallery/MCMC-Laplace/doc/entry-name">doc/entry-name</a>
 - <a href="../code-gallery/MCMC-Laplace/doc/exact-coefficient.png">doc/exact-coefficient.png</a>
 - <a href="../code-gallery/MCMC-Laplace/doc/exact-solution.png">doc/exact-solution.png</a>
 - <a href="../code-gallery/MCMC-Laplace/mcmc-laplace.cc">mcmc-laplace.cc</a>
@@ -322,8 +321,8 @@ that may take into account the current time, the amount of data
 written to disk over the past hour, the amount of internet traffic
 that has gone through the machine in the last hour, and similar pieces
 of pretty much random information. As a consequence, the seed is then
-pretty much guaranteed to be different from program invokation to
-program invokation, and consequently we will get different random
+pretty much guaranteed to be different from program invocation to
+program invocation, and consequently we will get different random
 number sequences every time. The output file is tagged with a string
 representation of this random seed, so that it is safe to run the same
 program multiple times at the same time in the same directory, with
@@ -565,6 +564,15 @@ that takes up a substantial fraction of the overall run time.
 <a name="ann-Matlab/exact_values.m"></a>
 <h1>Annotated version of Matlab/exact_values.m</h1>
 @code{.m}
+%% -----------------------------------------------------------------------------
+%%
+%% SPDX-License-Identifier: LGPL-2.1-or-later
+%% Copyright (C) 2022 by Wolfgang Bangerth
+%%
+%% This file is part of the deal.II code gallery.
+%%
+%% -----------------------------------------------------------------------------
+
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %%%%%%%%%%%% list of "exact" measurement values, z_hat %%%%%%%%%%%%%%%%%%%%
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
@@ -744,6 +752,15 @@ z_hat = [0.06076511762259369;
 <a name="ann-Matlab/forward_solver.m"></a>
 <h1>Annotated version of Matlab/forward_solver.m</h1>
 @code{.m}
+%% -----------------------------------------------------------------------------
+%%
+%% SPDX-License-Identifier: LGPL-2.1-or-later
+%% Copyright (C) 2022 by Wolfgang Bangerth
+%%
+%% This file is part of the deal.II code gallery.
+%%
+%% -----------------------------------------------------------------------------
+
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %%%%%%%%%%%%%%%%%%%%%% forward solver function %%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
@@ -796,6 +813,15 @@ z = M*U;
 <a name="ann-Matlab/get_statistics.m"></a>
 <h1>Annotated version of Matlab/get_statistics.m</h1>
 @code{.m}
+%% -----------------------------------------------------------------------------
+%%
+%% SPDX-License-Identifier: LGPL-2.1-or-later
+%% Copyright (C) 2022 by Wolfgang Bangerth
+%%
+%% This file is part of the deal.II code gallery.
+%%
+%% -----------------------------------------------------------------------------
+
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %%%%%%%%%%%%%%%%% compute statistics on data set %%%%%%%%%%%%%%%%%%%%%%%%%%
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
@@ -843,6 +869,15 @@ autocovar = autocovar(1:64,1:64,L:2*L-1)/N;
 <a name="ann-Matlab/log_probability.m"></a>
 <h1>Annotated version of Matlab/log_probability.m</h1>
 @code{.m}
+%% -----------------------------------------------------------------------------
+%%
+%% SPDX-License-Identifier: LGPL-2.1-or-later
+%% Copyright (C) 2022 by Wolfgang Bangerth
+%%
+%% This file is part of the deal.II code gallery.
+%%
+%% -----------------------------------------------------------------------------
+
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %%%%%%%%%%%%%%%%% compute log probability, log pi %%%%%%%%%%%%%%%%%%%%%%%%%
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
@@ -873,6 +908,15 @@ log_pi = log_L+log_pi_pr;
 <a name="ann-Matlab/main.m"></a>
 <h1>Annotated version of Matlab/main.m</h1>
 @code{.m}
+%% -----------------------------------------------------------------------------
+%%
+%% SPDX-License-Identifier: LGPL-2.1-or-later
+%% Copyright (C) 2022 by Wolfgang Bangerth
+%%
+%% This file is part of the deal.II code gallery.
+%%
+%% -----------------------------------------------------------------------------
+
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %%%%%%%%% Run MCMC sampler to estimate posterior distribution %%%%%%%%%%%%%
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
@@ -954,6 +998,15 @@ save (['data_N_' num2str(N) '_N_L_ ' num2str(N_L) '.mat'])
 <a name="ann-Matlab/plot_solution.m"></a>
 <h1>Annotated version of Matlab/plot_solution.m</h1>
 @code{.m}
+%% -----------------------------------------------------------------------------
+%%
+%% SPDX-License-Identifier: LGPL-2.1-or-later
+%% Copyright (C) 2022 by Wolfgang Bangerth
+%%
+%% This file is part of the deal.II code gallery.
+%%
+%% -----------------------------------------------------------------------------
+
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %%%%%%%%%%%%%%% plots solution, u, to Poisson equation %%%%%%%%%%%%%%%%%%%%
 %%%%%%%%%%%%%%%% associated to theta and a 32x32 mesh %%%%%%%%%%%%%%%%%%%%%
@@ -1012,6 +1065,15 @@ surf(xsp,xsp,zs)
 <a name="ann-Matlab/precomputations.m"></a>
 <h1>Annotated version of Matlab/precomputations.m</h1>
 @code{.m}
+%% -----------------------------------------------------------------------------
+%%
+%% SPDX-License-Identifier: LGPL-2.1-or-later
+%% Copyright (C) 2022 by Wolfgang Bangerth
+%%
+%% This file is part of the deal.II code gallery.
+%%
+%% -----------------------------------------------------------------------------
+
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %%%%%%% do all precomputations necessary for MCMC simulations %%%%%%%%%%%%%
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
@@ -1085,6 +1147,15 @@ save precomputations.mat
 <a name="ann-Python/forward_solver.py"></a>
 <h1>Annotated version of Python/forward_solver.py</h1>
 @code{.py}
+## -----------------------------------------------------------------------------
+##
+## SPDX-License-Identifier: LGPL-2.1-or-later
+## Copyright (C) 2022 by Wolfgang Bangerth
+##
+## This file is part of the deal.II code gallery.
+##
+## -----------------------------------------------------------------------------
+
 import numpy as np
 import scipy.sparse
 from scipy.sparse.linalg import spsolve
@@ -1373,27 +1444,19 @@ time_forward_solver()
  * 
  * 
  * @code
- *   /* ---------------------------------------------------------------------
+ *   /* -----------------------------------------------------------------------------
  *    *
- *    * Copyright (C) 2019 by the deal.II authors and Wolfgang Bangerth.
+ *    * SPDX-License-Identifier: LGPL-2.1-or-later
+ *    * Copyright (C) 2019 by Wolfgang Bangerth
  *    *
- *    * This file is part of the deal.II library.
+ *    * This file is part of the deal.II code gallery.
  *    *
- *    * The deal.II library is free software; you can use it, redistribute
- *    * it, and/or modify it under the terms of the GNU Lesser General
- *    * Public License as published by the Free Software Foundation; either
- *    * version 2.1 of the License, or (at your option) any later version.
- *    * The full text of the license can be found in the file LICENSE.md at
- *    * the top level directory of deal.II.
- *    *
- *    * ---------------------------------------------------------------------
- *   
+ *    * -----------------------------------------------------------------------------
  *    *
  *    * Author: Wolfgang Bangerth, Colorado State University, 2019.
  *    */
  *   
  *   
- *   
  *   #include <deal.II/base/timer.h>
  *   #include <deal.II/base/multithread_info.h>
  *   #include <deal.II/grid/tria.h>
