@@ -1,5 +1,5 @@
 /**
-@page code_gallery_Swift_Hohenberg-Solver The 'Generalized Swift-Hohenberg Equation Solve' code gallery program
+@page code_gallery_Swift_Hohenberg_Solver The 'Generalized Swift-Hohenberg Equation Solve' code gallery program
 @htmlonly
 <p align="center"> 
   This program was contributed by Samuel Scheuerman &lt;sam.scheuerman.051@gmail.com&gt;.
@@ -16,7 +16,6 @@ consists of the following files (click to inspect):
 - <a href="../code-gallery/Swift-Hohenberg-Solver/CMakeLists.txt">CMakeLists.txt</a>
 - <a href="../code-gallery/Swift-Hohenberg-Solver/Generalized-Swift-Hohenberg-Solver.cc">Generalized-Swift-Hohenberg-Solver.cc</a>
   (<a href="#ann-Generalized-Swift-Hohenberg-Solver.cc">annotated version</a>)
-- <a href="../code-gallery/Swift-Hohenberg-Solver/doc/entry-name">doc/entry-name</a>
 - <a href="../code-gallery/Swift-Hohenberg-Solver/doc/images/Cylinder_Hotspot_Table.png">doc/images/Cylinder_Hotspot_Table.png</a>
 - <a href="../code-gallery/Swift-Hohenberg-Solver/doc/images/Figures_1_and_2.png">doc/images/Figures_1_and_2.png</a>
 - <a href="../code-gallery/Swift-Hohenberg-Solver/doc/images/Refinement_Convergence_Table_1.png">doc/images/Refinement_Convergence_Table_1.png</a>
@@ -106,7 +105,7 @@ wavelength of $2\pi$. We choose $r = 0.3$ because solutions are
 reasonably well behaved for small values of $r$ and $g_1$, but there
 are interesting behaviors that occur when $g_1$ is smaller or larger
 than $r$ in magnitude, so this allows us room to vary $g_1$ and
-explore these behavior. To summarize, this code solves:
+explore these behavior. Additionally, we choose $r = 0.3$ because this matches the parameters used by Gurevich in [1]. We chose our parameters to match so that we could compare the output of our program to the results presented in [1], which was useful for validating that our code was functioning properly during the development process.  To summarize, this code solves:
 
 @f{align*}{
     \frac{\partial u}{\partial t} = 0.3u - (1 + \Delta)^2 u + g_1 u^2 - u^3
@@ -352,6 +351,11 @@ patterns that form. Each image sequence was taken at times 0, 10, 25,
 
 ![image](../code-gallery/Swift-Hohenberg-Solver/doc/images/Sinusoid_Random_Table.png)
 
+# References
+
+[1] Svetlana Gurevich. *Chapter 4: Swift-Hohenberg Equation*. url : https://www.uni-muenster.de/Physik.TP/archive/fileadmin/lehre/NumMethoden/SoSe10/Skript/SH.pdf.
+
+
 <a name="ann-Generalized-Swift-Hohenberg-Solver.cc"></a>
 <h1>Annotated version of Generalized-Swift-Hohenberg-Solver.cc</h1>
  * 
@@ -359,21 +363,14 @@ patterns that form. Each image sequence was taken at times 0, 10, 25,
  * 
  * 
  * @code
- *   /* ---------------------------------------------------------------------
+ *   /* -----------------------------------------------------------------------------
  *    *
- *    * Copyright (C) 2023 by the deal.II authors
+ *    * SPDX-License-Identifier: LGPL-2.1-or-later
+ *    * Copyright (C) 2023 by Samuel Scheuerman
  *    *
- *    * This file is part of the deal.II library.
+ *    * This file is part of the deal.II code gallery.
  *    *
- *    * The deal.II library is free software; you can use it, redistribute
- *    * it, and/or modify it under the terms of the GNU Lesser General
- *    * Public License as published by the Free Software Foundation; either
- *    * version 2.1 of the License, or (at your option) any later version.
- *    * The full text of the license can be found in the file LICENSE.md at
- *    * the top level directory of deal.II.
- *    *
- *    * ---------------------------------------------------------------------
- *   
+ *    * -----------------------------------------------------------------------------
  *    *
  *    * Author: Samuel Scheuerman, Colorado State University, 2023
  *    */
@@ -441,12 +438,12 @@ patterns that form. Each image sequence was taken at times 0, 10, 25,
  *   
  *   
  *   
- *     /** @brief This function warps points on a cyclindrical mesh by cosine wave along the central axis.
+ *     /** @brief This function warps points on a cylindrical mesh by cosine wave along the central axis.
  *      *         We use this function to generate the "sinusoid" mesh, which is the surface of revolution
  *      *         bounded by the cosine wave.
  *      *  @tparam spacedim This is the dimension of the embedding space, which is where the input point lives
  *      *  @param p This is the input point to be translated.
- *      *  @return The return as a tranlated point in the same dimensional space. This is the new point on the mesh.
+ *      *  @return The return as a translated point in the same dimensional space. This is the new point on the mesh.
  *      */
  *     template<int spacedim>
  *     Point<spacedim> transform_function(const Point<spacedim>&p)
@@ -461,7 +458,7 @@ patterns that form. Each image sequence was taken at times 0, 10, 25,
  *   
  * @endcode
  * 
- * Retruns a point where the x-coordinate is unchanged but the y and z coordinates are adjusted
+ * Returns a point where the x-coordinate is unchanged but the y and z coordinates are adjusted
  * by a cos wave of period 20, amplitude .5, and vertical shift 1
  * 
  * @code
@@ -615,7 +612,7 @@ patterns that form. Each image sequence was taken at times 0, 10, 25,
  *       double       time_step;
  * @endcode
  * 
- * / @brief Counts the number of iterations that have ellapsed
+ * / @brief Counts the number of iterations that have elapsed
  * 
  * @code
  *       unsigned int timestep_number;
@@ -1182,7 +1179,7 @@ patterns that form. Each image sequence was taken at times 0, 10, 25,
  *       , end_time(end_time)
  *     {}
  *   
- *     /** @brief              Distrubutes the finite element vectors to each DoF, creates the system matrix, solution, old_solution, and system_rhs vectors,
+ *     /** @brief              Distributes the finite element vectors to each DoF, creates the system matrix, solution, old_solution, and system_rhs vectors,
  *      *                      and outputs the number of DoF's to the console.
  *      *  @tparam dim         The dimension of the manifold
  *      *  @tparam spacedim    The dimension of the ambient space
@@ -1409,7 +1406,7 @@ patterns that form. Each image sequence was taken at times 0, 10, 25,
  *   
  * @endcode
  * 
- * Counts total time ellapsed
+ * Counts total time elapsed
  * 
  * @code
  *       time            = 0.0;
@@ -1479,7 +1476,7 @@ patterns that form. Each image sequence was taken at times 0, 10, 25,
  *   
  * @endcode
  * 
- * Loops over the cells to create the system matrix. We do this only once becase the timestep is constant
+ * Loops over the cells to create the system matrix. We do this only once because the timestep is constant
  * 
  * @code
  *       for(const auto &cell : dof_handler.active_cell_iterators()){
@@ -1763,13 +1760,13 @@ patterns that form. Each image sequence was taken at times 0, 10, 25,
  *   
  * @endcode
  * 
- * An array of mesh types. We itterate over this to allow for longer runs without having to stop the code
+ * An array of mesh types. We iterate over this to allow for longer runs without having to stop the code
  * 
  * @code
  *     MeshType mesh_types[5] = {HYPERCUBE, CYLINDER, SPHERE, TORUS, SINUSOID};
  * @endcode
  * 
- * An array of initial condition types. We itterate this as well, for the same reason
+ * An array of initial condition types. We iterate this as well, for the same reason
  * 
  * @code
  *     InitialConditionType ic_types[3] = {HOTSPOT, PSUEDORANDOM, RANDOM};
@@ -1821,7 +1818,7 @@ patterns that form. Each image sequence was taken at times 0, 10, 25,
  * @endcode
  * 
  * Switch statement that determines what template parameters are used by the solver object. Template parameters must be known at compile time, so we cannot
- * pass this as a varible unfortunately. In each case, we create a filename string (named appropriately for the particular case), output to the console what
+ * pass this as a variable unfortunately. In each case, we create a filename string (named appropriately for the particular case), output to the console what
  * we are running, create the solver object, and call run(). Note that for the cylinder, sphere, and sinusoid we decrease the refinement number by 1. This keeps
  * the number of dofs used in these cases comparable to the number of dofs on the 2D hypercube (otherwise the number of dofs is much larger). For the torus, we
  * decrease the refinement number by 2.
@@ -2030,7 +2027,7 @@ patterns that form. Each image sequence was taken at times 0, 10, 25,
  *           }
  *           catch (std::exception &exc)
  *           {
- *             std::cout << "An error occured" << std::endl;
+ *             std::cout << "An error occurred" << std::endl;
  *             std::cerr << std::endl
  *                       << std::endl
  *                       << "----------------------------------------------------"
@@ -2045,7 +2042,7 @@ patterns that form. Each image sequence was taken at times 0, 10, 25,
  *           }
  *           catch (...)
  *           {
- *             std::cout << "Error occured, made it past first catch" << std::endl;
+ *             std::cout << "Error occurred, made it past first catch" << std::endl;
  *             std::cerr << std::endl
  *                       << std::endl
  *                       << "----------------------------------------------------"
