@@ -14,7 +14,6 @@ consists of the following files (click to inspect):
 - <a href="../code-gallery/advection_reaction_estimator/README.md">README.md</a>
   (<a href="#ann-README.md">annotated version</a>)
 - <a href="../code-gallery/advection_reaction_estimator/CMakeLists.txt">CMakeLists.txt</a>
-- <a href="../code-gallery/advection_reaction_estimator/doc/entry-name">doc/entry-name</a>
 - <a href="../code-gallery/advection_reaction_estimator/doc/images/adaptive_vs_global_refinement.png">doc/images/adaptive_vs_global_refinement.png</a>
 - <a href="../code-gallery/advection_reaction_estimator/doc/images/refined_mesh_internal_layer.png">doc/images/refined_mesh_internal_layer.png</a>
 - <a href="../code-gallery/advection_reaction_estimator/doc/images/warp_by_scalar_solution_layer.png">doc/images/warp_by_scalar_solution_layer.png</a>
@@ -202,6 +201,16 @@ If we look at the decrease of the energy norm of the error in the globally refin
  * 
  * 
  * @code
+ *   /* -----------------------------------------------------------------------------
+ *    *
+ *    * SPDX-License-Identifier: LGPL-2.1-or-later
+ *    * Copyright (C) 2015 by Marco Feder
+ *    *
+ *    * This file is part of the deal.II code gallery.
+ *    *
+ *    * -----------------------------------------------------------------------------
+ *    */
+ *   
  *   #ifndef INCLUDE_DG_UPWIND_H_
  *   #define INCLUDE_DG_UPWIND_H_
  *   
@@ -394,6 +403,16 @@ If we look at the decrease of the energy norm of the error in the globally refin
  * 
  * 
  * @code
+ *   /* -----------------------------------------------------------------------------
+ *    *
+ *    * SPDX-License-Identifier: LGPL-2.1-or-later
+ *    * Copyright (C) 2015 by Marco Feder
+ *    *
+ *    * This file is part of the deal.II code gallery.
+ *    *
+ *    * -----------------------------------------------------------------------------
+ *    */
+ *   
  *   #include "include/DG_advection_reaction.h"
  *   
  *   int
@@ -466,23 +485,14 @@ If we look at the decrease of the energy norm of the error in the globally refin
  * 
  * 
  * @code
- *   /* ---------------------------------------------------------------------
+ *   /* -----------------------------------------------------------------------------
  *    *
- *    * Copyright (C) 2009 - 2021 by the deal.II authors
+ *    * SPDX-License-Identifier: LGPL-2.1-or-later
+ *    * Copyright (C) 2015 by Marco Feder
  *    *
- *    * This file is part of the deal.II library.
- *    *
- *    * The deal.II library is free software; you can use it, redistribute
- *    * it, and/or modify it under the terms of the GNU Lesser General
- *    * Public License as published by the Free Software Foundation; either
- *    * version 2.1 of the License, or (at your option) any later version.
- *    * The full text of the license can be found in the file LICENSE.md at
- *    * the top level directory of deal.II.
- *    *
- *    * ---------------------------------------------------------------------
- *    *
- *    * Author: Marco Feder, SISSA, 2021
+ *    * This file is part of the deal.II code gallery.
  *    *
+ *    * -----------------------------------------------------------------------------
  *    */
  *   
  *   #include "../include/DG_advection_reaction.h"
@@ -508,7 +518,7 @@ If we look at the decrease of the energy norm of the error in the globally refin
  * @endcode
  * 
  * 
- * <a name="TheScratchDataandCopyDataclasses"></a> 
+ * <a name="source/DG_advection_reaction.cc-TheScratchDataandCopyDataclasses"></a> 
  * <h3>The ScratchData and CopyData classes</h3>
  * 
 
@@ -599,7 +609,7 @@ If we look at the decrease of the energy norm of the error in the globally refin
  * @endcode
  * 
  * 
- * <a name="Auxiliaryfunction"></a> 
+ * <a name="source/DG_advection_reaction.cc-Auxiliaryfunction"></a> 
  * <h3>Auxiliary function</h3>
  * This auxiliary function is taken from step-74 and it's used to
  * compute the jump of the finite element function $u_h$ on a face.
@@ -981,7 +991,7 @@ If we look at the decrease of the energy norm of the error in the globally refin
  * @endcode
  * 
  * 
- * <a name="Meshrefinement"></a> 
+ * <a name="source/DG_advection_reaction.cc-Meshrefinement"></a> 
  * <h3>Mesh refinement</h3>
  * We refine the grid according the proposed estimator or with an approximation
  * to the gradient of the solution. The first option is the default one (you can
@@ -1105,7 +1115,7 @@ If we look at the decrease of the energy norm of the error in the globally refin
  * @endcode
  * 
  * 
- * <a name="Computetheenergynorm"></a> 
+ * <a name="source/DG_advection_reaction.cc-Computetheenergynorm"></a> 
  * <h3>Compute the energy norm</h3>
  * The energy norm is defined as $ |||\cdot ||| = \Bigl(||\cdot||_{0,\Omega}^2 +
  * \sum_{F \in \mathbb{F}}||c_F^{\frac{1}{2}}[\cdot] ||_{0,F}^2
@@ -1270,7 +1280,7 @@ If we look at the decrease of the energy norm of the error in the globally refin
  * @endcode
  * 
  * 
- * <a name="Computingtheestimator"></a> 
+ * <a name="source/DG_advection_reaction.cc-Computingtheestimator"></a> 
  * <h3>Computing the estimator</h3>
  * In the estimator, we have to compute the term $||f- c u_h - \Pi(f- c
  * u_h)||_{T}^{2}$ over a generic cell $T$. To achieve this, we first need to
@@ -1473,8 +1483,8 @@ If we look at the decrease of the energy norm of the error in the globally refin
  *   
  * @endcode
  * 
- * Here, we finally handle the assembly of the Mass matrix (M)_{ij} = (\phi_j,
- * \phi_i)_T. We pass in ScratchData and CopyData objects
+ * Here, we finally handle the assembly of the Mass matrix $(M)_{ij} = (\phi_j,
+ * \phi_i)_T$. We pass in ScratchData and CopyData objects
  * 
  * @code
  *     CopyData copy_data;
