@@ -2,7 +2,7 @@
 @page code_gallery_cdr The 'Convection Diffusion Reaction' code gallery program
 @htmlonly
 <p align="center"> 
-  This program was contributed by David R. Wells wellsd2@rpi.edu.
+  This program was contributed by David R. Wells &lt;wellsd2@rpi.edu&gt;.
   <br>
   It comes without any warranty or support by its authors or the authors of deal.II.
 </p>
@@ -37,7 +37,6 @@ consists of the following files (click to inspect):
   (<a href="#ann-common/source/system_rhs.cc">annotated version</a>)
 - <a href="../code-gallery/cdr/common/source/write_pvtu_output.cc">common/source/write_pvtu_output.cc</a>
   (<a href="#ann-common/source/write_pvtu_output.cc">annotated version</a>)
-- <a href="../code-gallery/cdr/doc/entry-name">doc/entry-name</a>
 - <a href="../code-gallery/cdr/parameters.prm">parameters.prm</a>
 - <a href="../code-gallery/cdr/solver/CMakeLists.txt">solver/CMakeLists.txt</a>
 - <a href="../code-gallery/cdr/solver/cdr.cc">solver/cdr.cc</a>
@@ -115,6 +114,16 @@ Problems" by Roos, Stynes, and Tobiska.
  * 
  * 
  * @code
+ *   /* -----------------------------------------------------------------------------
+ *    *
+ *    * SPDX-License-Identifier: LGPL-2.1-or-later
+ *    * Copyright (C) 2015 by David Wells
+ *    *
+ *    * This file is part of the deal.II code gallery.
+ *    *
+ *    * -----------------------------------------------------------------------------
+ *    */
+ *   
  *   #ifndef dealii__cdr_parameters_h
  *   #define dealii__cdr_parameters_h
  *   
@@ -176,6 +185,16 @@ Problems" by Roos, Stynes, and Tobiska.
  * 
  * 
  * @code
+ *   /* -----------------------------------------------------------------------------
+ *    *
+ *    * SPDX-License-Identifier: LGPL-2.1-or-later
+ *    * Copyright (C) 2015 by David Wells
+ *    *
+ *    * This file is part of the deal.II code gallery.
+ *    *
+ *    * -----------------------------------------------------------------------------
+ *    */
+ *   
  *   #ifndef dealii__cdr_system_matrix_h
  *   #define dealii__cdr_system_matrix_h
  *   #include <deal.II/base/quadrature_lib.h>
@@ -232,6 +251,16 @@ Problems" by Roos, Stynes, and Tobiska.
  * 
  * 
  * @code
+ *   /* -----------------------------------------------------------------------------
+ *    *
+ *    * SPDX-License-Identifier: LGPL-2.1-or-later
+ *    * Copyright (C) 2015 by David Wells
+ *    *
+ *    * This file is part of the deal.II code gallery.
+ *    *
+ *    * -----------------------------------------------------------------------------
+ *    */
+ *   
  *   #ifndef dealii__cdr_system_matrix_templates_h
  *   #define dealii__cdr_system_matrix_templates_h
  *   #include <deal.II/base/quadrature_lib.h>
@@ -393,6 +422,16 @@ Problems" by Roos, Stynes, and Tobiska.
  * 
  * 
  * @code
+ *   /* -----------------------------------------------------------------------------
+ *    *
+ *    * SPDX-License-Identifier: LGPL-2.1-or-later
+ *    * Copyright (C) 2015 by David Wells
+ *    *
+ *    * This file is part of the deal.II code gallery.
+ *    *
+ *    * -----------------------------------------------------------------------------
+ *    */
+ *   
  *   #ifndef dealii__cdr_system_rhs_h
  *   #define dealii__cdr_system_rhs_h
  *   #include <deal.II/base/point.h>
@@ -441,6 +480,16 @@ Problems" by Roos, Stynes, and Tobiska.
  * 
  * 
  * @code
+ *   /* -----------------------------------------------------------------------------
+ *    *
+ *    * SPDX-License-Identifier: LGPL-2.1-or-later
+ *    * Copyright (C) 2015 by David Wells
+ *    *
+ *    * This file is part of the deal.II code gallery.
+ *    *
+ *    * -----------------------------------------------------------------------------
+ *    */
+ *   
  *   #ifndef dealii__cdr_system_rhs_templates_h
  *   #define dealii__cdr_system_rhs_templates_h
  *   #include <deal.II/base/point.h>
@@ -582,6 +631,16 @@ Problems" by Roos, Stynes, and Tobiska.
  * 
  * 
  * @code
+ *   /* -----------------------------------------------------------------------------
+ *    *
+ *    * SPDX-License-Identifier: LGPL-2.1-or-later
+ *    * Copyright (C) 2015 by David Wells
+ *    *
+ *    * This file is part of the deal.II code gallery.
+ *    *
+ *    * -----------------------------------------------------------------------------
+ *    */
+ *   
  *   #ifndef dealii__cdr_write_pvtu_output_h
  *   #define dealii__cdr_write_pvtu_output_h
  *   #include <deal.II/dofs/dof_handler.h>
@@ -623,6 +682,16 @@ Problems" by Roos, Stynes, and Tobiska.
  * 
  * 
  * @code
+ *   /* -----------------------------------------------------------------------------
+ *    *
+ *    * SPDX-License-Identifier: LGPL-2.1-or-later
+ *    * Copyright (C) 2015 by David Wells
+ *    *
+ *    * This file is part of the deal.II code gallery.
+ *    *
+ *    * -----------------------------------------------------------------------------
+ *    */
+ *   
  *   #ifndef dealii__cdr_write_pvtu_output_templates_h
  *   #define dealii__cdr_write_pvtu_output_templates_h
  *   #include <deal.II/base/data_out_base.h>
@@ -678,8 +747,7 @@ Problems" by Roos, Stynes, and Tobiska.
  * <code>best_speed</code> makes this function much faster.
  * 
  * @code
- *       flags.compression_level =
- *         DataOutBase::VtkFlags::ZlibCompressionLevel::best_speed;
+ *       flags.compression_level = DataOutBase::CompressionLevel::best_speed;
  *       data_out.set_flags(flags);
  *   
  *       unsigned int subdomain_n;
@@ -721,6 +789,23 @@ Problems" by Roos, Stynes, and Tobiska.
 <h1>Annotated version of common/source/parameters.cc</h1>
  * 
  * 
+ * 
+ * -----------------------------------------------------------------------------
+ * 
+
+ * 
+ * SPDX-License-Identifier: LGPL-2.1-or-later
+ * Copyright (C) 2015 by David Wells
+ * 
+
+ * 
+ * This file is part of the deal.II code gallery.
+ * 
+
+ * 
+ * -----------------------------------------------------------------------------
+ * 
+
  * 
  * 
  * @code
@@ -878,6 +963,16 @@ Problems" by Roos, Stynes, and Tobiska.
  * 
  * 
  * @code
+ *   /* -----------------------------------------------------------------------------
+ *    *
+ *    * SPDX-License-Identifier: LGPL-2.1-or-later
+ *    * Copyright (C) 2015 by David Wells
+ *    *
+ *    * This file is part of the deal.II code gallery.
+ *    *
+ *    * -----------------------------------------------------------------------------
+ *    */
+ *   
  *   #include <deal.II/lac/sparse_matrix.h>
  *   #include <deal.II/lac/trilinos_sparse_matrix.h>
  *   
@@ -983,6 +1078,16 @@ Problems" by Roos, Stynes, and Tobiska.
  * 
  * 
  * @code
+ *   /* -----------------------------------------------------------------------------
+ *    *
+ *    * SPDX-License-Identifier: LGPL-2.1-or-later
+ *    * Copyright (C) 2015 by David Wells
+ *    *
+ *    * This file is part of the deal.II code gallery.
+ *    *
+ *    * -----------------------------------------------------------------------------
+ *    */
+ *   
  *   #include <deal.II/lac/sparse_matrix.h>
  *   #include <deal.II/lac/trilinos_sparse_matrix.h>
  *   #include <deal.II/lac/trilinos_vector.h>
@@ -1058,6 +1163,16 @@ Problems" by Roos, Stynes, and Tobiska.
  * 
  * 
  * @code
+ *   /* -----------------------------------------------------------------------------
+ *    *
+ *    * SPDX-License-Identifier: LGPL-2.1-or-later
+ *    * Copyright (C) 2015 by David Wells
+ *    *
+ *    * This file is part of the deal.II code gallery.
+ *    *
+ *    * -----------------------------------------------------------------------------
+ *    */
+ *   
  *   #include <deal.II/lac/trilinos_vector.h>
  *   #include <deal.II/lac/vector.h>
  *   
@@ -1112,6 +1227,16 @@ Problems" by Roos, Stynes, and Tobiska.
  * 
  * 
  * @code
+ *   /* -----------------------------------------------------------------------------
+ *    *
+ *    * SPDX-License-Identifier: LGPL-2.1-or-later
+ *    * Copyright (C) 2015 by David Wells
+ *    *
+ *    * This file is part of the deal.II code gallery.
+ *    *
+ *    * -----------------------------------------------------------------------------
+ *    */
+ *   
  *   #include <deal.II/base/conditional_ostream.h>
  *   #include <deal.II/base/quadrature_lib.h>
  *   
@@ -1288,8 +1413,8 @@ Problems" by Roos, Stynes, and Tobiska.
  *     dof_handler.distribute_dofs(fe);
  *     pcout << "Number of degrees of freedom: " << dof_handler.n_dofs()
  *           << std::endl;
- *     locally_owned_dofs = dof_handler.locally_owned_dofs();
- *     DoFTools::extract_locally_relevant_dofs(dof_handler, locally_relevant_dofs);
+ *     locally_owned_dofs    = dof_handler.locally_owned_dofs();
+ *     locally_relevant_dofs = DoFTools::extract_locally_relevant_dofs(dof_handler);
  *   
  *     constraints.clear();
  *     constraints.reinit(locally_relevant_dofs);
@@ -1311,7 +1436,7 @@ Problems" by Roos, Stynes, and Tobiska.
  *   void
  *   CDRProblem<dim>::setup_system()
  *   {
- *     DynamicSparsityPattern dynamic_sparsity_pattern(dof_handler.n_dofs());
+ *     DynamicSparsityPattern dynamic_sparsity_pattern(locally_relevant_dofs);
  *     DoFTools::make_sparsity_pattern(dof_handler,
  *                                     dynamic_sparsity_pattern,
  *                                     constraints,
