@@ -13,11 +13,11 @@ This program is part of the @ref CodeGallery "deal.II code gallery" and
 consists of the following files (click to inspect):
 - <a href="../code-gallery/coupled_laplace_problem/README.md">README.md</a>
   (<a href="#ann-README.md">annotated version</a>)
-- <a href="../code-gallery/coupled_laplace_problem/Allclean">Allclean</a>
+- <a href="../code-gallery/coupled_laplace_problem/Allclean.sh">Allclean.sh</a>
+  (<a href="#ann-Allclean.sh">annotated version</a>)
 - <a href="../code-gallery/coupled_laplace_problem/CMakeLists.txt">CMakeLists.txt</a>
 - <a href="../code-gallery/coupled_laplace_problem/coupled_laplace_problem.cc">coupled_laplace_problem.cc</a>
   (<a href="#ann-coupled_laplace_problem.cc">annotated version</a>)
-- <a href="../code-gallery/coupled_laplace_problem/doc/entry-name">doc/entry-name</a>
 - <a href="../code-gallery/coupled_laplace_problem/doc/result.gif">doc/result.gif</a>
 - <a href="../code-gallery/coupled_laplace_problem/fancy_boundary_condition.cc">fancy_boundary_condition.cc</a>
   (<a href="#ann-fancy_boundary_condition.cc">annotated version</a>)
@@ -53,7 +53,7 @@ Coupled simulations deal mostly with time-dependent problems. Hence, we make the
   \\
   u &= g(t) \qquad\qquad & \text{on}\ \partial\Omega_c.
 @f}
-with the fixed Dirichlet boundary \Omega_s, the coupling boundary \Omega_c and the time-dependent coupling data g(t).
+with the fixed Dirichlet boundary $\Omega_s$, the coupling boundary $\Omega_c$ and the time-dependent coupling data $g(t)$.
 
 The system is consequently discretized by a first-order backward Euler method, resulting in
 @f{align*}
@@ -107,11 +107,67 @@ By default, the results are saved in each time step using `vtk` files, which can
 * [The preCICE reference paper](https://www.sciencedirect.com/science/article/abs/pii/S0045793016300974)
 
 
+<a name="ann-Allclean.sh"></a>
+<h1>Annotated version of Allclean.sh</h1>
+@code{.sh}
+## -----------------------------------------------------------------------------
+##
+## SPDX-License-Identifier: LGPL-2.1-or-later
+## Copyright (C) 2020 by David Schneider
+## Copyright (C) 2020 by Benjamin Uekermann
+##
+## This file is part of the deal.II code gallery.
+##
+## -----------------------------------------------------------------------------
+
+#!/bin/sh
+cd ${0%/*} || exit 1    # Run from this directory
+
+echo "Cleaning..."
+
+# Participant 1: coupled_laplace_problem
+Participant1="coupled_laplace_problem"
+
+# Participant 2: fancy_boundary_condition
+Participant2="fancy_boundary_condition"
+
+# Remove vtk result files
+rm -fv solution-*.vtk
+
+# Remove the preCICE-related log files
+echo "Deleting the preCICE log files..."
+rm -fv \
+    precice-*.log \
+    precice-*-events.json
+    
+rm -rfv precice-run
+rm -fv .${Participant1}-${Participant2}.address
+
+echo "Cleaning complete!"
+#------------------------------------------------------------------------------
+@endcode
+
+
 <a name="ann-coupled_laplace_problem.cc"></a>
 <h1>Annotated version of coupled_laplace_problem.cc</h1>
  * 
  * 
  * 
+ * 
+ * @code
+ *   /* -----------------------------------------------------------------------------
+ *    *
+ *    * SPDX-License-Identifier: LGPL-2.1-or-later
+ *    * Copyright (C) 2020 by David Schneider
+ *    * Copyright (C) 2020 by Benjamin Uekermann
+ *    *
+ *    * This file is part of the deal.II code gallery.
+ *    *
+ *    * -----------------------------------------------------------------------------
+ *    */
+ *   
+ * @endcode
+ * 
  * The included deal.II header files are the same as in the other example
  * programs:
  * 
@@ -148,7 +204,7 @@ By default, the results are saved in each time step using `vtk` files, which can
  * to obtain access to preCICE specific functionality
  * 
  * @code
- *   #include <precice/SolverInterface.hpp>
+ *   #include <precice/precice.hpp>
  *   
  *   #include <fstream>
  *   #include <iostream>
@@ -199,21 +255,24 @@ By default, the results are saved in each time step using `vtk` files, which can
  *     Adapter(const ParameterClass &   parameters,
  *             const types::boundary_id dealii_boundary_interface_id);
  *   
- *     double
+ *     void
  *     initialize(const DoFHandler<dim> &                    dof_handler,
  *                std::map<types::global_dof_index, double> &boundary_data,
  *                const MappingQGeneric<dim> &               mapping);
  *   
- *     double
- *     advance(std::map<types::global_dof_index, double> &boundary_data,
- *             const double                               computed_timestep_length);
+ *     void
+ *     read_data(double                                     relative_read_time,
+ *               std::map<types::global_dof_index, double> &boundary_data);
+ *   
+ *     void
+ *     advance(const double computed_timestep_length);
  *   
  * @endcode
  * 
  * public precCICE solver interface
  * 
  * @code
- *     precice::SolverInterface precice;
+ *     precice::Participant precice;
  *   
  * @endcode
  * 
@@ -240,12 +299,10 @@ By default, the results are saved in each time step using `vtk` files, which can
  *   
  * @endcode
  * 
- * These IDs are filled by preCICE during the initialization. We set a default
- * value of -1 in order to detect potential errors more easily.
+ * The node IDs are filled by preCICE during the initialization and associated to
+ * the spherical vertices we pass to preCICE
  * 
  * @code
- *     int mesh_id;
- *     int read_data_id;
  *     int n_interface_nodes;
  *   
  * @endcode
@@ -263,12 +320,12 @@ By default, the results are saved in each time step using `vtk` files, which can
  * 
  * @code
  *     std::vector<int>    interface_nodes_ids;
- *     std::vector<double> read_data;
+ *     std::vector<double> read_data_buffer;
  *   
  * @endcode
  * 
  * The MPI rank and total number of MPI ranks is required by preCICE when the
- * SolverInterface is created. Since this tutorial runs only in serial mode we
+ * Participant is created. Since this tutorial runs only in serial mode we
  * define the variables manually in this class instead of using the regular
  * MPI interface.
  * 
@@ -292,7 +349,7 @@ By default, the results are saved in each time step using `vtk` files, which can
  * @endcode
  * 
  * In the constructor of the Adapter class, we set up the preCICE
- * SolverInterface. We need to tell preCICE our name as participant of the
+ * Participant. We need to tell preCICE our name as participant of the
  * simulation and the name of the preCICE configuration file. Both have already
  * been specified in the CouplingParameter class above. Thus, we pass the class
  * directly to the constructor and read out all relevant information. As a
@@ -323,29 +380,18 @@ By default, the results are saved in each time step using `vtk` files, which can
  * the associated interface(s). The `boundary_data` is an empty map, which is
  * filled by preCICE, i.e., information of the other participant. Throughout
  * the system assembly, the map can directly be used in order to apply the
- * Dirichlet boundary conditions in the linear system. preCICE returns the
- * maximum admissible time-step size during the initialization.
+ * Dirichlet boundary conditions in the linear system.
  * 
  * @code
  *   template <int dim, typename ParameterClass>
- *   double
+ *   void
  *   Adapter<dim, ParameterClass>::initialize(
  *     const DoFHandler<dim> &                    dof_handler,
  *     std::map<types::global_dof_index, double> &boundary_data,
  *     const MappingQGeneric<dim> &               mapping)
  *   {
  *     Assert(dim > 1, ExcNotImplemented());
- *     AssertDimension(dim, precice.getDimensions());
- *   
- * @endcode
- * 
- * In a first step, we get preCICE specific IDs from preCICE and store them in
- * the respective variables. Later, they are used for data transfer.
- * 
- * @code
- *     mesh_id      = precice.getMeshID(mesh_name);
- *     read_data_id = precice.getDataID(read_data_name, mesh_id);
- *   
+ *     AssertDimension(dim, precice.getMeshDimensions(mesh_name));
  *   
  * @endcode
  * 
@@ -404,10 +450,10 @@ By default, the results are saved in each time step using `vtk` files, which can
  * is read/written per interface node.
  * 
  * @code
- *     read_data.resize(n_interface_nodes);
+ *     read_data_buffer.resize(n_interface_nodes);
  * @endcode
  * 
- * The IDs are again filled by preCICE during the initializations.
+ * The IDs are filled by preCICE during the initializations.
  * 
  * @code
  *     interface_nodes_ids.resize(n_interface_nodes);
@@ -437,10 +483,9 @@ By default, the results are saved in each time step using `vtk` files, which can
  * information to preCICE.
  * 
  * @code
- *     precice.setMeshVertices(mesh_id,
- *                             n_interface_nodes,
- *                             interface_nodes_positions.data(),
- *                             interface_nodes_ids.data());
+ *     precice.setMeshVertices(mesh_name,
+ *                             interface_nodes_positions,
+ *                             interface_nodes_ids);
  *   
  * @endcode
  * 
@@ -448,86 +493,68 @@ By default, the results are saved in each time step using `vtk` files, which can
  * `initialize()`
  * 
  * @code
- *     const double max_delta_t = precice.initialize();
- *   
+ *     precice.initialize();
+ *   }
  *   
+ *   template <int dim, typename ParameterClass>
+ *   void
+ *   Adapter<dim, ParameterClass>::read_data(
+ *     double                                     relative_read_time,
+ *     std::map<types::global_dof_index, double> &boundary_data)
+ *   {
  * @endcode
  * 
- * read first coupling data from preCICE if available (i.e. deal.II is
- * the second participant in a serial coupling scheme)
+ * here, we obtain data, i.e. the boundary condition, from another
+ * participant. We have already vertex IDs and just need to convert our
+ * obtained data to the deal.II compatible 'boundary map' , which is done in
+ * the format_deal_to_precice function.
  * 
  * @code
- *     if (precice.isReadDataAvailable())
- *       {
- *         precice.readBlockScalarData(read_data_id,
- *                                     n_interface_nodes,
- *                                     interface_nodes_ids.data(),
- *                                     read_data.data());
+ *     precice.readData(mesh_name,
+ *                      read_data_name,
+ *                      interface_nodes_ids,
+ *                      relative_read_time,
+ *                      read_data_buffer);
  *   
  * @endcode
  * 
- * After receiving the coupling data in `read_data`, we convert it to
+ * After receiving the coupling data in `read_data_buffer`, we convert it to
  * the std::map `boundary_data` which is later needed in order to apply
  * Dirichlet boundary conditions
  * 
  * @code
- *         format_precice_to_dealii(boundary_data);
- *       }
- *   
- *     return max_delta_t;
+ *     format_precice_to_dealii(boundary_data);
  *   }
  *   
  *   
  * @endcode
  * 
  * The function `advance()` is called in the main time loop after the
- * computation in each time step. Here,
- * coupling data is passed to and obtained from preCICE.
+ * computation in each time step. Here, preCICE exchanges the coupling data
+ * internally and computes mappings as well as acceleration methods.
  * 
  * @code
  *   template <int dim, typename ParameterClass>
- *   double
- *   Adapter<dim, ParameterClass>::advance(
- *     std::map<types::global_dof_index, double> &boundary_data,
- *     const double                               computed_timestep_length)
+ *   void
+ *   Adapter<dim, ParameterClass>::advance(const double computed_timestep_length)
  *   {
  * @endcode
  * 
- * We specify the computed time-step length and pass it to preCICE. In
- * return, preCICE tells us the maximum admissible time-step size our
- * participant is allowed to compute in order to not exceed the next coupling
- * time step.
+ * We specify the computed time-step length and pass it to preCICE.
  * 
  * @code
- *     const double max_delta_t = precice.advance(computed_timestep_length);
- *   
- * @endcode
- * 
- * As a next step, we obtain data, i.e. the boundary condition, from another
- * participant. We have already all IDs and just need to convert our obtained
- * data to the deal.II compatible 'boundary map' , which is done in the
- * format_deal_to_precice function.
- * 
- * @code
- *     precice.readBlockScalarData(read_data_id,
- *                                 n_interface_nodes,
- *                                 interface_nodes_ids.data(),
- *                                 read_data.data());
- *   
- *     format_precice_to_dealii(boundary_data);
- *   
- *     return max_delta_t;
+ *     precice.advance(computed_timestep_length);
  *   }
  *   
  *   
  *   
  * @endcode
  * 
- * This function takes the std::vector obtained by preCICE in `read_data` and
+ * This function takes the std::vector obtained by preCICE in `read_data_buffer` and
  * inserts the values to the right position in the boundary map used throughout
  * our deal.II solver for Dirichlet boundary conditions. The function is only
  * used internally in the Adapter class and not called in the solver itself. The
- * order, in which preCICE sorts the data in the `read_data` vector is exactly
+ * order, in which preCICE sorts the data in the `read_data_buffer` vector is exactly
  * the same as the order of the initially passed vertices coordinates.
  * 
  * @code
@@ -545,8 +572,8 @@ By default, the results are saved in each time step using `vtk` files, which can
  *     auto dof_component = boundary_data.begin();
  *     for (int i = 0; i < n_interface_nodes; ++i)
  *       {
- *         AssertIndexRange(i, read_data.size());
- *         boundary_data[dof_component->first] = read_data[i];
+ *         AssertIndexRange(i, read_data_buffer.size());
+ *         boundary_data[dof_component->first] = read_data_buffer[i];
  *         ++dof_component;
  *       }
  *   }
@@ -610,7 +637,7 @@ By default, the results are saved in each time step using `vtk` files, which can
  *   
  * @endcode
  * 
- * The time-step size delta_t is the acutual time-step size used for all
+ * The time-step size delta_t is the actual time-step size used for all
  * computations. The preCICE time-step size is obtained by preCICE in order to
  * ensure a synchronization at all coupling time steps. The solver time
  * step-size is the desired time-step size of our individual solver. In more
@@ -897,13 +924,11 @@ By default, the results are saved in each time step using `vtk` files, which can
  *   
  * @endcode
  * 
- * After we set up the system, we initialize preCICE using the functionalities
- * of the Adapter. preCICE returns the maximum admissible time-step size,
- * which needs to be compared to our desired solver time-step size.
+ * After we set up the system, we initialize preCICE and the adapter using the
+ * functionalities of the Adapter.
  * 
  * @code
- *     precice_delta_t = adapter.initialize(dof_handler, boundary_data, mapping);
- *     delta_t         = std::min(precice_delta_t, solver_delta_t);
+ *     adapter.initialize(dof_handler, boundary_data, mapping);
  *   
  * @endcode
  * 
@@ -921,6 +946,24 @@ By default, the results are saved in each time step using `vtk` files, which can
  *         ++time_step;
  * @endcode
  * 
+ * preCICE returns the maximum admissible time-step size,
+ * which needs to be compared to our desired solver time-step size.
+ * 
+ * @code
+ *         precice_delta_t = adapter.precice.getMaxTimeStepSize();
+ *         delta_t         = std::min(precice_delta_t, solver_delta_t);
+ * @endcode
+ * 
+ * Next we read data. Since we use a fully backward Euler method, we want
+ * the data to be associated to the end of the current time-step (delta_t)
+ * Time-interpolation methods in preCICE allow to get readData at any
+ * point in time, if the coupling scheme allows it
+ * 
+ * @code
+ *         adapter.read_data(delta_t, boundary_data);
+ *   
+ * @endcode
+ * 
  * In the time loop, we assemble the coupled system and solve it as
  * usual.
  * 
@@ -932,14 +975,10 @@ By default, the results are saved in each time step using `vtk` files, which can
  * 
  * After we solved the system, we advance the coupling to the next time
  * level. In a bi-directional coupled simulation, we would pass our
- * calculated data to and obtain new data from preCICE. Here, we simply
- * obtain new data from preCICE, so from the other participant. As before,
- * we obtain a maximum time-step size and compare it against the desired
- * solver time-step size.
+ * calculated data to preCICE
  * 
  * @code
- *         precice_delta_t = adapter.advance(boundary_data, delta_t);
- *         delta_t         = std::min(precice_delta_t, solver_delta_t);
+ *         adapter.advance(delta_t);
  *   
  * @endcode
  * 
@@ -973,14 +1012,30 @@ By default, the results are saved in each time step using `vtk` files, which can
  * 
  * 
  * 
+ * 
+ * @code
+ *   /* -----------------------------------------------------------------------------
+ *    *
+ *    * SPDX-License-Identifier: LGPL-2.1-or-later
+ *    * Copyright (C) 2020 by David Schneider
+ *    * Copyright (C) 2020 by Benjamin Uekermann
+ *    *
+ *    * This file is part of the deal.II code gallery.
+ *    *
+ *    * -----------------------------------------------------------------------------
+ *    */
+ *   
+ * @endcode
+ * 
  * This program does not use any deal.II functionality and depends only on
  * preCICE and the standard libraries.
  * 
  * @code
- *   #include <precice/SolverInterface.hpp>
+ *   #include <precice/precice.hpp>
  *   
  *   #include <iostream>
  *   #include <sstream>
+ *   #include <vector>
  *   
  * @endcode
  * 
@@ -1050,17 +1105,11 @@ By default, the results are saved in each time step using `vtk` files, which can
  *     const int commRank = 0;
  *     const int commSize = 1;
  *   
- *     precice::SolverInterface precice(solverName,
- *                                      configFileName,
- *                                      commRank,
- *                                      commSize);
+ *     precice::Participant precice(solverName, configFileName, commRank, commSize);
  *   
- *     const int meshID           = precice.getMeshID(meshName);
- *     const int dimensions       = precice.getDimensions();
+ *     const int dimensions       = precice.getMeshDimensions(meshName);
  *     const int numberOfVertices = 6;
  *   
- *     const int dataID = precice.getDataID(dataWriteName, meshID);
- *   
  * @endcode
  * 
  * Set up data structures
@@ -1100,27 +1149,45 @@ By default, the results are saved in each time step using `vtk` files, which can
  * Pass the vertices to preCICE
  * 
  * @code
- *     precice.setMeshVertices(meshID,
- *                             numberOfVertices,
- *                             vertices.data(),
- *                             vertexIDs.data());
+ *     precice.setMeshVertices(meshName, vertices, vertexIDs);
  *   
  * @endcode
  * 
- * initialize the Solverinterface
+ * Variables for the time
  * 
  * @code
- *     double dt = precice.initialize();
+ *     const double end_time = 1;
+ *     double       time     = 0;
+ *   
+ * @endcode
+ * 
+ * Not used in the configuration by default
+ * 
+ * @code
+ *     if (precice.requiresInitialData())
+ *       {
+ *         std::cout << "Boundary participant: writing initial data \n";
+ *         define_boundary_values(writeData, time, end_time);
+ *         precice.writeData(meshName, dataWriteName, vertexIDs, writeData);
+ *       }
+ *   
+ * @endcode
+ * 
+ * initialize the Participant
+ * 
+ * @code
+ *     precice.initialize();
  *   
  * @endcode
  * 
  * Start time loop
  * 
  * @code
- *     const double end_time = 1;
- *     double       time     = 0;
  *     while (precice.isCouplingOngoing())
  *       {
+ *         double dt = precice.getMaxTimeStepSize();
+ *         time += dt;
+ *   
  * @endcode
  * 
  * Generate new boundary data
@@ -1128,18 +1195,11 @@ By default, the results are saved in each time step using `vtk` files, which can
  * @code
  *         define_boundary_values(writeData, time, end_time);
  *   
- *         {
- *           std::cout << "Boundary participant: writing coupling data \n";
- *           precice.writeBlockScalarData(dataID,
- *                                        numberOfVertices,
- *                                        vertexIDs.data(),
- *                                        writeData.data());
- *         }
+ *         std::cout << "Boundary participant: writing coupling data \n";
+ *         precice.writeData(meshName, dataWriteName, vertexIDs, writeData);
  *   
- *         dt = precice.advance(dt);
  *         std::cout << "Boundary participant: advancing in time\n";
- *   
- *         time += dt;
+ *         precice.advance(dt);
  *       }
  *   
  *     std::cout << "Boundary participant: closing...\n";
