@@ -15,7 +15,6 @@ consists of the following files (click to inspect):
   (<a href="#ann-Readme.md">annotated version</a>)
 - <a href="../code-gallery/information_based_mesh_refinement/CMakeLists.txt">CMakeLists.txt</a>
 - <a href="../code-gallery/information_based_mesh_refinement/doc/adjoint.png">doc/adjoint.png</a>
-- <a href="../code-gallery/information_based_mesh_refinement/doc/entry-name">doc/entry-name</a>
 - <a href="../code-gallery/information_based_mesh_refinement/doc/recovered-forward-solution.png">doc/recovered-forward-solution.png</a>
 - <a href="../code-gallery/information_based_mesh_refinement/doc/recovered-parameter.png">doc/recovered-parameter.png</a>
 - <a href="../code-gallery/information_based_mesh_refinement/doc/synthetic.png">doc/synthetic.png</a>
@@ -123,26 +122,18 @@ this code gallery program. See the paper for captions and more information.
  * 
  * 
  * @code
- *   ﻿/* ---------------------------------------------------------------------
+ *   ﻿/* -----------------------------------------------------------------------------
  *    *
- *    * Copyright (C) 2022 by the deal.II authors and Wolfgang Bangerth.
+ *    * SPDX-License-Identifier: LGPL-2.1-or-later
+ *    * Copyright (C) 2022 by Wolfgang Bangerth
  *    *
- *    * This file is part of the deal.II library.
+ *    * This file is part of the deal.II code gallery.
  *    *
- *    * The deal.II library is free software; you can use it, redistribute
- *    * it, and/or modify it under the terms of the GNU Lesser General
- *    * Public License as published by the Free Software Foundation; either
- *    * version 2.1 of the License, or (at your option) any later version.
- *    * The full text of the license can be found in the file LICENSE.md at
- *    * the top level directory of deal.II.
- *    *
- *    * ---------------------------------------------------------------------
- *   
+ *    * -----------------------------------------------------------------------------
  *    *
  *    * Author: Wolfgang Bangerth, Colorado State University, 2022.
  *    */
  *   
- *   
  *   #include <deal.II/base/numbers.h>
  *   #include <deal.II/base/thread_management.h>
  *   #include <deal.II/grid/tria.h>
@@ -588,7 +579,7 @@ this code gallery program. See the paper for captions and more information.
  *   
  *     std::vector<unsigned int> local_dof_indices (dofs_per_cell);
  *   
- *     FEValuesExtractors::Scalar c(0), lambda(1), f(2);
+ *     const FEValuesExtractors::Scalar c(0), lambda(1), f(2);
  *   
  *     for (const auto &cell : dof_handler.active_cell_iterators())
  *       {
@@ -993,7 +984,7 @@ this code gallery program. See the paper for captions and more information.
  *         QGauss<dim> quadrature(3);
  *         FEValues<dim> fe_values (fe, quadrature, update_values | update_JxW_values);
  *   
- *         FEValuesExtractors::Scalar lambda(1), f(2);
+ *         const FEValuesExtractors::Scalar lambda(1), f(2);
  *   
  *         std::vector<double> lambda_values (quadrature.size());
  *         std::vector<double> f_values (quadrature.size());
