@@ -14,7 +14,6 @@ consists of the following files (click to inspect):
 - <a href="../code-gallery/parallel_in_time/Readme.md">Readme.md</a>
   (<a href="#ann-Readme.md">annotated version</a>)
 - <a href="../code-gallery/parallel_in_time/CMakeLists.txt">CMakeLists.txt</a>
-- <a href="../code-gallery/parallel_in_time/doc/entry-name">doc/entry-name</a>
 - <a href="../code-gallery/parallel_in_time/doc/results/gridConvergence.png">doc/results/gridConvergence.png</a>
 - <a href="../code-gallery/parallel_in_time/doc/results/strongscaling.png">doc/results/strongscaling.png</a>
 - <a href="../code-gallery/parallel_in_time/src/BraidFuncs.cc">src/BraidFuncs.cc</a>
@@ -191,7 +190,7 @@ This is expected behavior as second order finite elements are used.
 Code Organization
 -----------------
 
-#### The src directory
+### The src directory
 
 The entry point of the code is in parallel\_in\_time.cc and sets up XBraid for a simulation.
 The XBraid setup involves initializing the app struct and configuring XBraid for the desired number of timesteps, number of iterations, and so forth.
@@ -200,12 +199,12 @@ The HeatEquation class and all deal.II functionality is declared in `HeatEquatio
 Since HeatEquation is a class template, its definition file `HeatEquationImplem.hh` is included at the bottom of `HeatEquation.hh`.
 Lastly various helper functions and variables such as the current processor id and the output stream are declared in `Utilities.hh` and defined in `Utilities.cc`.
 
-#### The test directory
+### The test directory
 
 This directory contains tests to be built and run with CMake.
 These tests verify the correct implementation of the various functions.
 
-#### The doc directory
+### The doc directory
 
 This directory is for storing further documentation of the code.
 Not much is in this directory right now as most of the documentation is in the Readme or in comments of the source code files.
@@ -305,6 +304,16 @@ This code base does not use spatial subdomains with AMR and so could provide an
  * 
  * 
  * @code
+ *   /* -----------------------------------------------------------------------------
+ *    *
+ *    * SPDX-License-Identifier: LGPL-2.1-or-later
+ *    * Copyright (C) 2018 by Joshua Christopher
+ *    *
+ *    * This file is part of the deal.II code gallery.
+ *    *
+ *    * -----------------------------------------------------------------------------
+ *    */
+ *   
  *   #include "BraidFuncs.hh"
  *   
  * @endcode
@@ -518,7 +527,7 @@ This code base does not use spatial subdomains with AMR and so could provide an
  * This function packs a linear buffer with data so that the buffer
  * may be sent to another processor via MPI. The buffer is cast to
  * a type we can work with. The first element of the buffer is the
- * size of the buffer. Then we iterate over soltuion vector u and
+ * size of the buffer. Then we iterate over solution vector u and
  * fill the buffer with our solution data. Finally we tell XBraid
  * how much data we wrote.
  * 
@@ -545,7 +554,7 @@ This code base does not use spatial subdomains with AMR and so could provide an
  *   
  * @endcode
  * 
- * This function unpacks a buffer that was recieved from a different
+ * This function unpacks a buffer that was received from a different
  * processor via MPI. The size of the buffer is read from the first
  * element, then we iterate over the size of the buffer and fill
  * the values of solution vector u with the data in the buffer.
@@ -584,6 +593,16 @@ This code base does not use spatial subdomains with AMR and so could provide an
  * 
  * 
  * @code
+ *   /* -----------------------------------------------------------------------------
+ *    *
+ *    * SPDX-License-Identifier: LGPL-2.1-or-later
+ *    * Copyright (C) 2018 by Joshua Christopher
+ *    *
+ *    * This file is part of the deal.II code gallery.
+ *    *
+ *    * -----------------------------------------------------------------------------
+ *    */
+ *   
  *   #ifndef _BRAIDFUNCS_H_
  *   #define _BRAIDFUNCS_H_
  *   
@@ -613,7 +632,7 @@ This code base does not use spatial subdomains with AMR and so could provide an
  * 
  * This struct contains all data that changes with time. For now
  * this is just the solution data. When doing AMR this should
- * probably include the triangulization, the sparsity patter,
+ * probably include the triangulization, the sparsity pattern,
  * constraints, etc.
  * 
  * @code
@@ -829,6 +848,16 @@ This code base does not use spatial subdomains with AMR and so could provide an
  * 
  * 
  * @code
+ *   /* -----------------------------------------------------------------------------
+ *    *
+ *    * SPDX-License-Identifier: LGPL-2.1-or-later
+ *    * Copyright (C) 2018 by Joshua Christopher
+ *    *
+ *    * This file is part of the deal.II code gallery.
+ *    *
+ *    * -----------------------------------------------------------------------------
+ *    */
+ *   
  *   #ifndef _HEATEQUATION_H_
  *   #define _HEATEQUATION_H_
  *   
@@ -1050,6 +1079,16 @@ This code base does not use spatial subdomains with AMR and so could provide an
  * 
  * 
  * @code
+ *   /* -----------------------------------------------------------------------------
+ *    *
+ *    * SPDX-License-Identifier: LGPL-2.1-or-later
+ *    * Copyright (C) 2018 by Joshua Christopher
+ *    *
+ *    * This file is part of the deal.II code gallery.
+ *    *
+ *    * -----------------------------------------------------------------------------
+ *    */
+ *   
  *   #include "Utilities.hh"
  *   
  *   #include <iomanip>
@@ -1502,6 +1541,16 @@ This code base does not use spatial subdomains with AMR and so could provide an
  * 
  * 
  * @code
+ *   /* -----------------------------------------------------------------------------
+ *    *
+ *    * SPDX-License-Identifier: LGPL-2.1-or-later
+ *    * Copyright (C) 2018 by Joshua Christopher
+ *    *
+ *    * This file is part of the deal.II code gallery.
+ *    *
+ *    * -----------------------------------------------------------------------------
+ *    */
+ *   
  *   #include "Utilities.hh"
  *   
  *   #include <string>
@@ -1511,6 +1560,7 @@ This code base does not use spatial subdomains with AMR and so could provide an
  *   
  *   int procID = 0;
  *   
+ *   #ifdef USE_MPI
  * @endcode
  * 
  * The shared variables
@@ -1526,7 +1576,6 @@ This code base does not use spatial subdomains with AMR and so could provide an
  *   static bool              s_pout_init = false ;
  *   static bool              s_pout_open = false ;
  *   
- *   #ifdef USE_MPI
  * @endcode
  * 
  * in parallel, compute the filename give the basename
@@ -1561,26 +1610,6 @@ This code base does not use spatial subdomains with AMR and so could provide an
  * @code
  *     s_pout_open = (bool)s_pout ;
  *   }
- *   
- *   #else
- * @endcode
- * 
- * in serial, filename is always cout
- * 
- * @code
- *   static void setFileName()
- *   {
- *     s_pout_filename = "cout" ;
- *   }
- *   
- * @endcode
- * 
- * in serial, this does absolutely nothing
- * 
- * @code
- *   static void openFile()
- *   {
- *   }
  *   #endif
  *   
  *   std::ostream& pout()
@@ -1614,7 +1643,7 @@ This code base does not use spatial subdomains with AMR and so could provide an
  *           }
  * @endcode
  * 
- * if MPI not initialized, we cant open the file so return cout
+ * if MPI not initialized, we can't open the file so return cout
  * 
  * @code
  *         if ( ! flag_i || flag_f)
@@ -1653,6 +1682,16 @@ This code base does not use spatial subdomains with AMR and so could provide an
  * 
  * 
  * @code
+ *   /* -----------------------------------------------------------------------------
+ *    *
+ *    * SPDX-License-Identifier: LGPL-2.1-or-later
+ *    * Copyright (C) 2018 by Joshua Christopher
+ *    *
+ *    * This file is part of the deal.II code gallery.
+ *    *
+ *    * -----------------------------------------------------------------------------
+ *    */
+ *   
  *   #ifndef _UTILITIES_H_
  *   #define _UTILITIES_H_
  *   
@@ -1695,21 +1734,14 @@ This code base does not use spatial subdomains with AMR and so could provide an
  * 
  * 
  * @code
- *   /* ---------------------------------------------------------------------
+ *   /* -----------------------------------------------------------------------------
  *    *
- *    * Copyright (C) 2013 - 2018 by the deal.II authors
+ *    * SPDX-License-Identifier: LGPL-2.1-or-later
+ *    * Copyright (C) 2018 by Joshua Christopher
  *    *
- *    * This file is part of the deal.II library.
+ *    * This file is part of the deal.II code gallery.
  *    *
- *    * The deal.II library is free software; you can use it, redistribute
- *    * it, and/or modify it under the terms of the GNU Lesser General
- *    * Public License as published by the Free Software Foundation; either
- *    * version 2.1 of the License, or (at your option) any later version.
- *    * The full text of the license can be found in the file LICENSE at
- *    * the top level of the deal.II distribution.
- *    *
- *    * ---------------------------------------------------------------------
- *   
+ *    * -----------------------------------------------------------------------------
  *    *
  *    * Author: Joshua Christopher, Colorado State University, 2018
  *    */
@@ -1858,6 +1890,16 @@ This code base does not use spatial subdomains with AMR and so could provide an
  * 
  * 
  * @code
+ *   /* -----------------------------------------------------------------------------
+ *    *
+ *    * SPDX-License-Identifier: LGPL-2.1-or-later
+ *    * Copyright (C) 2018 by Joshua Christopher
+ *    *
+ *    * This file is part of the deal.II code gallery.
+ *    *
+ *    * -----------------------------------------------------------------------------
+ *    */
+ *   
  *   #include "BraidFuncs.hh"
  *   
  *   #include <braid.h>
