@@ -14,7 +14,6 @@ consists of the following files (click to inspect):
 - <a href="../code-gallery/time_dependent_navier_stokes/Readme.md">Readme.md</a>
   (<a href="#ann-Readme.md">annotated version</a>)
 - <a href="../code-gallery/time_dependent_navier_stokes/CMakeLists.txt">CMakeLists.txt</a>
-- <a href="../code-gallery/time_dependent_navier_stokes/doc/entry-name">doc/entry-name</a>
 - <a href="../code-gallery/time_dependent_navier_stokes/doc/partition.png">doc/partition.png</a>
 - <a href="../code-gallery/time_dependent_navier_stokes/doc/scaling.png">doc/scaling.png</a>
 - <a href="../code-gallery/time_dependent_navier_stokes/doc/velocity-mesh-adaption.avi">doc/velocity-mesh-adaption.avi</a>
@@ -69,7 +68,7 @@ and $c(u;u, v)$ is the convection term:
 c(u;u, v) = \int_{\Omega} (u \cdot \nabla u) \cdot v d\Omega
 @f}
 
-Substracting $m(u^n, v) + \Delta{t}a((u^n, p^n), (v, q))$ from both sides of the equation,
+Subtracting $m(u^n, v) + \Delta{t}a((u^n, p^n), (v, q))$ from both sides of the equation,
 we have the incremental form:
 @f{eqnarray*}
 m(\Delta{u}, v) + \Delta{t}\cdot a((\Delta{u}, \Delta{p}), (v, q)) = \Delta{t}(-a(u^n, p^n), (q, v)) - \Delta{t}c(u^n;u^n, v)
@@ -100,7 +99,7 @@ The system we want to solve can be written in matrix form:
     \right)
 @f}
 
-#### Grad-Div stablization ####
+#### Grad-Div stabilization ####
 
 Similar to step-57, we add $\gamma B^T M_p^{-1} B$ to the upper left block of the system. This is a 
 term that is consistent, i.e., the corresponding operators applied to the exact solution would
@@ -133,7 +132,7 @@ With this, the system becomes:
 @f}
 where $\tilde{A} = A + \gamma B^T M_p^{-1} B$.
 
-A detailed explanation of the Grad-Div stablization can be found in [1].
+A detailed explanation of the Grad-Div stabilization can be found in [1].
 
 #### Block preconditioner ####
 
@@ -190,6 +189,18 @@ on my numerical formulation and implementation.
  * 
  * 
  * @code
+ *   /* -----------------------------------------------------------------------------
+ *    *
+ *    * SPDX-License-Identifier: LGPL-2.1-or-later
+ *    * Copyright (C) 2017 Jie Cheng
+ *    *
+ *    * This file is part of the deal.II code gallery.
+ *    *
+ *    * -----------------------------------------------------------------------------
+ *    *
+ *    * Author: Jie Cheng <chengjiehust@gmail.com>
+ *    */
+ *   
  *   #include <deal.II/base/function.h>
  *   #include <deal.II/base/logstream.h>
  *   #include <deal.II/base/quadrature_lib.h>
@@ -252,7 +263,7 @@ on my numerical formulation and implementation.
  * @endcode
  * 
  * 
- * <a name="Createthetriangulation"></a> 
+ * <a name="time_dependent_navier_stokes.cc-Createthetriangulation"></a> 
  * <h3>Create the triangulation</h3>
  * The code to create triangulation is copied from
  * [Martin Kronbichler's
@@ -262,7 +273,7 @@ on my numerical formulation and implementation.
 
  * 
  * 
- * <a name="Helperfunction"></a> 
+ * <a name="time_dependent_navier_stokes.cc-Helperfunction"></a> 
  * <h4>Helper function</h4>
  * 
  * @code
@@ -380,7 +391,7 @@ on my numerical formulation and implementation.
  *   
  * @endcode
  * 
- * Left domain is requred in 3d only.
+ * Left domain is required in 3d only.
  * 
  * @code
  *       if (compute_in_2d)
@@ -397,7 +408,7 @@ on my numerical formulation and implementation.
  * @endcode
  * 
  * 
- * <a name="2Dflowaroundcylindertriangulation"></a> 
+ * <a name="time_dependent_navier_stokes.cc-2Dflowaroundcylindertriangulation"></a> 
  * <h4>2D flow around cylinder triangulation</h4>
  * 
  * @code
@@ -446,7 +457,7 @@ on my numerical formulation and implementation.
  * @endcode
  * 
  * 
- * <a name="3Dflowaroundcylindertriangulation"></a> 
+ * <a name="time_dependent_navier_stokes.cc-3Dflowaroundcylindertriangulation"></a> 
  * <h4>3D flow around cylinder triangulation</h4>
  * 
  * @code
@@ -505,7 +516,7 @@ on my numerical formulation and implementation.
  * @endcode
  * 
  * 
- * <a name="Timestepping"></a> 
+ * <a name="time_dependent_navier_stokes.cc-Timestepping"></a> 
  * <h3>Time stepping</h3>
  * This class is pretty much self-explanatory.
  * 
@@ -563,7 +574,7 @@ on my numerical formulation and implementation.
  * @endcode
  * 
  * 
- * <a name="Boundaryvalues"></a> 
+ * <a name="time_dependent_navier_stokes.cc-Boundaryvalues"></a> 
  * <h3>Boundary values</h3>
  * Dirichlet boundary conditions for the velocity inlet and walls.
  * 
@@ -620,7 +631,7 @@ on my numerical formulation and implementation.
  * @endcode
  * 
  * 
- * <a name="Blockpreconditioner"></a> 
+ * <a name="time_dependent_navier_stokes.cc-Blockpreconditioner"></a> 
  * <h3>Block preconditioner</h3>
  *   
 
@@ -699,7 +710,7 @@ on my numerical formulation and implementation.
  * @endcode
  * 
  * 
- * <a name="BlockSchurPreconditionerBlockSchurPreconditioner"></a> 
+ * <a name="time_dependent_navier_stokes.cc-BlockSchurPreconditionerBlockSchurPreconditioner"></a> 
  * <h4>BlockSchurPreconditioner::BlockSchurPreconditioner</h4>
  *   
 
@@ -753,7 +764,7 @@ on my numerical formulation and implementation.
  * @endcode
  * 
  * 
- * <a name="BlockSchurPreconditionervmult"></a> 
+ * <a name="time_dependent_navier_stokes.cc-BlockSchurPreconditionervmult"></a> 
  * <h4>BlockSchurPreconditioner::vmult</h4>
  *   
 
@@ -785,8 +796,7 @@ on my numerical formulation and implementation.
  *         TimerOutput::Scope timer_section(timer, "CG for Mp");
  *         SolverControl mp_control(src.block(1).size(),
  *                                  1e-6 * src.block(1).l2_norm());
- *         PETScWrappers::SolverCG cg_mp(mp_control,
- *                                       mass_schur->get_mpi_communicator());
+ *         PETScWrappers::SolverCG cg_mp(mp_control);
  * @endcode
  * 
  * $-(\nu + \gamma)M_p^{-1}v_1$
@@ -807,8 +817,7 @@ on my numerical formulation and implementation.
  *         TimerOutput::Scope timer_section(timer, "CG for Sm");
  *         SolverControl sm_control(src.block(1).size(),
  *                                  1e-6 * src.block(1).l2_norm());
- *         PETScWrappers::SolverCG cg_sm(sm_control,
- *                                       mass_schur->get_mpi_communicator());
+ *         PETScWrappers::SolverCG cg_sm(sm_control);
  * @endcode
  * 
  * PreconditionBlockJacobi works find on Sm if we do not refine the mesh.
@@ -847,8 +856,7 @@ on my numerical formulation and implementation.
  *         TimerOutput::Scope timer_section(timer, "CG for A");
  *         SolverControl a_control(src.block(0).size(),
  *                                 1e-6 * src.block(0).l2_norm());
- *         PETScWrappers::SolverCG cg_a(a_control,
- *                                      mass_schur->get_mpi_communicator());
+ *         PETScWrappers::SolverCG cg_a(a_control);
  * @endcode
  * 
  * We do not use any preconditioner for this block, which is of course
@@ -868,7 +876,7 @@ on my numerical formulation and implementation.
  * @endcode
  * 
  * 
- * <a name="TheincompressibleNavierStokessolver"></a> 
+ * <a name="time_dependent_navier_stokes.cc-TheincompressibleNavierStokessolver"></a> 
  * <h3>The incompressible Navier-Stokes solver</h3>
  *   
 
@@ -880,7 +888,7 @@ on my numerical formulation and implementation.
  * The system equation is written in the incremental form, and we treat
  * the convection term explicitly. Therefore the system equation is linear
  * and symmetric, which does not need to be solved with Newton's iteration.
- * The system is further stablized and preconditioned with Grad-Div method,
+ * The system is further stabilized and preconditioned with Grad-Div method,
  * where GMRES solver is used as the outer solver.
  * 
  * @code
@@ -996,7 +1004,7 @@ on my numerical formulation and implementation.
  * @endcode
  * 
  * 
- * <a name="InsIMEXInsIMEX"></a> 
+ * <a name="time_dependent_navier_stokes.cc-InsIMEXInsIMEX"></a> 
  * <h4>InsIMEX::InsIMEX</h4>
  * 
  * @code
@@ -1021,7 +1029,7 @@ on my numerical formulation and implementation.
  * @endcode
  * 
  * 
- * <a name="InsIMEXsetup_dofs"></a> 
+ * <a name="time_dependent_navier_stokes.cc-InsIMEXsetup_dofs"></a> 
  * <h4>InsIMEX::setup_dofs</h4>
  * 
  * @code
@@ -1057,7 +1065,7 @@ on my numerical formulation and implementation.
  *       owned_partitioning[0] = dof_handler.locally_owned_dofs().get_view(0, dof_u);
  *       owned_partitioning[1] =
  *         dof_handler.locally_owned_dofs().get_view(dof_u, dof_u + dof_p);
- *       DoFTools::extract_locally_relevant_dofs(dof_handler, locally_relevant_dofs);
+ *       locally_relevant_dofs = DoFTools::extract_locally_relevant_dofs(dof_handler);
  *       relevant_partitioning.resize(2);
  *       relevant_partitioning[0] = locally_relevant_dofs.get_view(0, dof_u);
  *       relevant_partitioning[1] =
@@ -1071,7 +1079,7 @@ on my numerical formulation and implementation.
  * @endcode
  * 
  * 
- * <a name="InsIMEXmake_constraints"></a> 
+ * <a name="time_dependent_navier_stokes.cc-InsIMEXmake_constraints"></a> 
  * <h4>InsIMEX::make_constraints</h4>
  * 
  * @code
@@ -1103,7 +1111,7 @@ on my numerical formulation and implementation.
  *       else
  *         dirichlet_bc_ids = std::vector<unsigned int>{0, 2, 3, 4, 5, 6};
  *   
- *       FEValuesExtractors::Vector velocities(0);
+ *       const FEValuesExtractors::Vector velocities(0);
  *       for (auto id : dirichlet_bc_ids)
  *         {
  *           VectorTools::interpolate_boundary_values(dof_handler,
@@ -1125,7 +1133,7 @@ on my numerical formulation and implementation.
  * @endcode
  * 
  * 
- * <a name="InsIMEXinitialize_system"></a> 
+ * <a name="time_dependent_navier_stokes.cc-InsIMEXinitialize_system"></a> 
  * <h4>InsIMEX::initialize_system</h4>
  * 
  * @code
@@ -1188,7 +1196,7 @@ on my numerical formulation and implementation.
  * @endcode
  * 
  * 
- * <a name="InsIMEXassemble"></a> 
+ * <a name="time_dependent_navier_stokes.cc-InsIMEXassemble"></a> 
  * <h4>InsIMEX::assemble</h4>
  *   
 
@@ -1354,7 +1362,7 @@ on my numerical formulation and implementation.
  * @endcode
  * 
  * 
- * <a name="InsIMEXsolve"></a> 
+ * <a name="time_dependent_navier_stokes.cc-InsIMEXsolve"></a> 
  * <h4>InsIMEX::solve</h4>
  * Solve the linear system using FGMRES solver with block preconditioner.
  * After solving the linear system, the same AffineConstraints object as used
@@ -1409,7 +1417,7 @@ on my numerical formulation and implementation.
  * @endcode
  * 
  * 
- * <a name="InsIMEXrun"></a> 
+ * <a name="time_dependent_navier_stokes.cc-InsIMEXrun"></a> 
  * <h4>InsIMEX::run</h4>
  * 
  * @code
@@ -1459,7 +1467,7 @@ on my numerical formulation and implementation.
  * 
  * We have to assemble the LHS for the initial two time steps:
  * once using nonzero_constraints, once using zero_constraints,
- * as well as the steps imediately after mesh refinement.
+ * as well as the steps immediately after mesh refinement.
  * 
  * @code
  *           bool assemble_system = (time.get_timestep() < 3 || refined);
@@ -1498,7 +1506,7 @@ on my numerical formulation and implementation.
  * @endcode
  * 
  * 
- * <a name="InsIMEXoutput_result"></a> 
+ * <a name="time_dependent_navier_stokes.cc-InsIMEXoutput_result"></a> 
  * <h4>InsIMEX::output_result</h4>
  *   
 
@@ -1574,7 +1582,7 @@ on my numerical formulation and implementation.
  * @endcode
  * 
  * 
- * <a name="InsIMEXrefine_mesh"></a> 
+ * <a name="time_dependent_navier_stokes.cc-InsIMEXrefine_mesh"></a> 
  * <h4>InsIMEX::refine_mesh</h4>
  *   
 
@@ -1589,7 +1597,7 @@ on my numerical formulation and implementation.
  *       pcout << "Refining mesh..." << std::endl;
  *   
  *       Vector<float> estimated_error_per_cell(triangulation.n_active_cells());
- *       FEValuesExtractors::Vector velocity(0);
+ *       const FEValuesExtractors::Vector velocity(0);
  *       KellyErrorEstimator<dim>::estimate(dof_handler,
  *                                          face_quad_formula,
  *                                          {},
@@ -1659,7 +1667,7 @@ on my numerical formulation and implementation.
  * @endcode
  * 
  * 
- * <a name="mainfunction"></a> 
+ * <a name="time_dependent_navier_stokes.cc-mainfunction"></a> 
  * <h3>main function</h3>
  * 
 
