@@ -1,3 +1,15 @@
+/* -----------------------------------------------------------------------------
+ *
+ * SPDX-License-Identifier: LGPL-2.1-or-later
+ * Copyright (C) 2017 Jie Cheng
+ *
+ * This file is part of the deal.II code gallery.
+ *
+ * -----------------------------------------------------------------------------
+ *
+ * Author: Jie Cheng <chengjiehust@gmail.com>
+ */
+
 #include <deal.II/base/function.h>
 #include <deal.II/base/logstream.h>
 #include <deal.II/base/quadrature_lib.h>
@@ -160,7 +172,7 @@ namespace fluid
     // refinement:
     GridGenerator::flatten_triangulation(middle, tmp2);
 
-    // Left domain is requred in 3d only.
+    // Left domain is required in 3d only.
     if (compute_in_2d)
       {
         GridGenerator::merge_triangulations(tmp2, right, tria);
@@ -542,7 +554,7 @@ namespace fluid
   // The system equation is written in the incremental form, and we treat
   // the convection term explicitly. Therefore the system equation is linear
   // and symmetric, which does not need to be solved with Newton's iteration.
-  // The system is further stablized and preconditioned with Grad-Div method,
+  // The system is further stabilized and preconditioned with Grad-Div method,
   // where GMRES solver is used as the outer solver.
   template <int dim>
   class InsIMEX
@@ -653,7 +665,7 @@ namespace fluid
     owned_partitioning[0] = dof_handler.locally_owned_dofs().get_view(0, dof_u);
     owned_partitioning[1] =
       dof_handler.locally_owned_dofs().get_view(dof_u, dof_u + dof_p);
-    DoFTools::extract_locally_relevant_dofs(dof_handler, locally_relevant_dofs);
+    locally_relevant_dofs = DoFTools::extract_locally_relevant_dofs(dof_handler);
     relevant_partitioning.resize(2);
     relevant_partitioning[0] = locally_relevant_dofs.get_view(0, dof_u);
     relevant_partitioning[1] =
@@ -685,7 +697,7 @@ namespace fluid
     else
       dirichlet_bc_ids = std::vector<unsigned int>{0, 2, 3, 4, 5, 6};
 
-    FEValuesExtractors::Vector velocities(0);
+    const FEValuesExtractors::Vector velocities(0);
     for (auto id : dirichlet_bc_ids)
       {
         VectorTools::interpolate_boundary_values(dof_handler,
@@ -973,7 +985,7 @@ namespace fluid
         bool apply_nonzero_constraints = (time.get_timestep() == 1);
         // We have to assemble the LHS for the initial two time steps:
         // once using nonzero_constraints, once using zero_constraints,
-        // as well as the steps imediately after mesh refinement.
+        // as well as the steps immediately after mesh refinement.
         bool assemble_system = (time.get_timestep() < 3 || refined);
         refined = false;
         assemble(apply_nonzero_constraints, assemble_system);
@@ -1069,7 +1081,7 @@ namespace fluid
     pcout << "Refining mesh..." << std::endl;
 
     Vector<float> estimated_error_per_cell(triangulation.n_active_cells());
-    FEValuesExtractors::Vector velocity(0);
+    const FEValuesExtractors::Vector velocity(0);
     KellyErrorEstimator<dim>::estimate(dof_handler,
                                        face_quad_formula,
                                        {},
