@@ -1,3 +1,13 @@
+/* -----------------------------------------------------------------------------
+ *
+ * SPDX-License-Identifier: LGPL-2.1-or-later
+ * Copyright (C) 2016 Manuel Quezada de Luna
+ *
+ * This file is part of the deal.II code gallery.
+ *
+ * -----------------------------------------------------------------------------
+ */
+
 #include <deal.II/base/quadrature_lib.h>
 #include <deal.II/base/function.h>
 #include <deal.II/lac/affine_constraints.h>
@@ -187,19 +197,16 @@ void MultiPhase<dim>::setup()
 {
   // setup system LS
   dof_handler_LS.distribute_dofs (fe_LS);
-  locally_owned_dofs_LS = dof_handler_LS.locally_owned_dofs ();
-  DoFTools::extract_locally_relevant_dofs (dof_handler_LS,
-                                           locally_relevant_dofs_LS);
+  locally_owned_dofs_LS    = dof_handler_LS.locally_owned_dofs ();
+  locally_relevant_dofs_LS = DoFTools::extract_locally_relevant_dofs (dof_handler_LS);
   // setup system U
   dof_handler_U.distribute_dofs (fe_U);
-  locally_owned_dofs_U = dof_handler_U.locally_owned_dofs ();
-  DoFTools::extract_locally_relevant_dofs (dof_handler_U,
-                                           locally_relevant_dofs_U);
+  locally_owned_dofs_U    = dof_handler_U.locally_owned_dofs ();
+  locally_relevant_dofs_U = DoFTools::extract_locally_relevant_dofs (dof_handler_U);
   // setup system P //
   dof_handler_P.distribute_dofs (fe_P);
-  locally_owned_dofs_P = dof_handler_P.locally_owned_dofs ();
-  DoFTools::extract_locally_relevant_dofs (dof_handler_P,
-                                           locally_relevant_dofs_P);
+  locally_owned_dofs_P    = dof_handler_P.locally_owned_dofs ();
+  locally_relevant_dofs_P = DoFTools::extract_locally_relevant_dofs (dof_handler_P);
   // init vectors for phi
   locally_relevant_solution_phi.reinit(locally_owned_dofs_LS,locally_relevant_dofs_LS,mpi_communicator);
   locally_relevant_solution_phi = 0;
@@ -259,7 +266,11 @@ template <int dim>
 void MultiPhase<dim>::init_constraints()
 {
   constraints.clear ();
+#if DEAL_II_VERSION_GTE(9, 6, 0)
+  constraints.reinit (locally_owned_dofs_LS, locally_relevant_dofs_LS);
+#else
   constraints.reinit (locally_relevant_dofs_LS);
+#endif
   DoFTools::make_hanging_node_constraints (dof_handler_LS, constraints);
   constraints.close ();
 }
@@ -499,7 +510,7 @@ void MultiPhase<dim>::run()
   //////////////////////////////////////
   cK = 1.0;
   cE = 1.0;
-  sharpness_integer=10; //this will be multipled by min_h
+  sharpness_integer=10; //this will be multiplied by min_h
   //TRANSPORT_TIME_INTEGRATION=FORWARD_EULER;
   TRANSPORT_TIME_INTEGRATION=SSP33;
   //ALGORITHM = "MPP_u1";
@@ -627,7 +638,6 @@ int main(int argc, char *argv[])
     {
       using namespace dealii;
       Utilities::MPI::MPI_InitFinalize mpi_initialization(argc, argv, 1);
-      PetscInitialize(&argc, &argv, nullptr, nullptr);
       deallog.depth_console (0);
       {
         unsigned int degree_LS = 1;
@@ -635,7 +645,6 @@ int main(int argc, char *argv[])
         MultiPhase<2> multi_phase(degree_LS, degree_U);
         multi_phase.run();
       }
-      PetscFinalize();
     }
 
   catch (std::exception &exc)
