@@ -4,5 +4,7 @@ var searchData=
   ['instantiate_5fdltg_5fmatrix_1',['INSTANTIATE_DLTG_MATRIX',['../affine__constraints_8cc.html#aa658ff19173c453be557629531249c5f',1,'affine_constraints.cc']]],
   ['instantiate_5fdltg_5fvector_2',['INSTANTIATE_DLTG_VECTOR',['../affine__constraints_8cc.html#a4b818db7271bf2c2b2f55483149dcb42',1,'affine_constraints.cc']]],
   ['instantiate_5fdltg_5fvectormatrix_3',['INSTANTIATE_DLTG_VECTORMATRIX',['../affine__constraints_8cc.html#a03c61c0e01099e0ddbb5ec4fc6391bd2',1,'affine_constraints.cc']]],
-  ['instantiateumfpack_4',['InstantiateUMFPACK',['../sparse__direct_8cc.html#a587f83f81285e1ee32fe4f3a12a7b148',1,'sparse_direct.cc']]]
+  ['instantiatemumps_4',['InstantiateMUMPS',['../sparse__direct_8cc.html#a8e92db67c4f6cae6d42128df754f286b',1,'sparse_direct.cc']]],
+  ['instantiatemumpsmatvec_5',['InstantiateMUMPSMatVec',['../sparse__direct_8cc.html#ab6da2603f616f38c2840b674b206b056',1,'sparse_direct.cc']]],
+  ['instantiateumfpack_6',['InstantiateUMFPACK',['../sparse__direct_8cc.html#a587f83f81285e1ee32fe4f3a12a7b148',1,'sparse_direct.cc']]]
 ];
