@@ -3,7 +3,7 @@ var searchData=
   ['object_0',['Object',['../classGeometryPrimitive.html#a8e0cad3ba3bc8f9cbe7fb4e8eaed66a2',1,'GeometryPrimitive']]],
   ['optimizationflags_1',['OptimizationFlags',['../namespaceDifferentiation_1_1SD.html#af920b6488de218dea94f25b94ad08842',1,'Differentiation::SD']]],
   ['optimizertype_2',['OptimizerType',['../namespaceDifferentiation_1_1SD.html#a841a7b84dc17bf2ba675522093a97e8b',1,'Differentiation::SD']]],
-  ['orthogonalizationstrategy_3',['OrthogonalizationStrategy',['../namespaceLinearAlgebra.html#a711c39096eb12afb61e779ade1f19dcb',1,'LinearAlgebra']]],
+  ['orthogonalizationstrategy_3',['OrthogonalizationStrategy',['../classSUNDIALS_1_1KINSOL_1_1AdditionalData.html#a62ccb862c04e1f1cf53e6489fd6fedda',1,'SUNDIALS::KINSOL::AdditionalData::OrthogonalizationStrategy'],['../namespaceLinearAlgebra.html#a711c39096eb12afb61e779ade1f19dcb',1,'LinearAlgebra::OrthogonalizationStrategy']]],
   ['outputdata_4',['OutputData',['../classTimerOutput.html#aba3bc552db540d876d14e3c7870fe1f8',1,'TimerOutput']]],
   ['outputformat_5',['OutputFormat',['../classGridOut.html#af24aadcd00f93b7f428f44ecd40c44d9',1,'GridOut::OutputFormat'],['../namespaceDataOutBase.html#aa3cbced9f1d4ae661f13018f4c980aa1',1,'DataOutBase::OutputFormat']]],
   ['outputfrequency_6',['OutputFrequency',['../classTimerOutput.html#a643d0e642b80048e91b37109fe9357cb',1,'TimerOutput']]],
