@@ -1,8 +1,8 @@
 var searchData=
 [
-  ['read_5fwrite_5fvector_2ecc_0',['read_write_vector.cc',['../read__write__vector_8cc.html',1,'']]],
-  ['read_5fwrite_5fvector_2eh_1',['read_write_vector.h',['../read__write__vector_8h.html',1,'']]],
-  ['read_5fwrite_5fvector_5fcuda_2ecc_2',['read_write_vector_cuda.cc',['../read__write__vector__cuda_8cc.html',1,'']]],
+  ['read_5fvector_2eh_0',['read_vector.h',['../read__vector_8h.html',1,'']]],
+  ['read_5fwrite_5fvector_2ecc_1',['read_write_vector.cc',['../read__write__vector_8cc.html',1,'']]],
+  ['read_5fwrite_5fvector_2eh_2',['read_write_vector.h',['../read__write__vector_8h.html',1,'']]],
   ['reference_5fcell_2ecc_3',['reference_cell.cc',['../reference__cell_8cc.html',1,'']]],
   ['reference_5fcell_2eh_4',['reference_cell.h',['../reference__cell_8h.html',1,'']]],
   ['refinement_2ecc_5',['refinement.cc',['../refinement_8cc.html',1,'']]],
