@@ -3,5 +3,6 @@ var searchData=
   ['keep_5findependent_5fvalues_0',['keep_independent_values',['../structDifferentiation_1_1AD_1_1TapedDrivers.html#ad4f88e01c2bae722271f2b7abc841623',1,'Differentiation::AD::TapedDrivers']]],
   ['king_5fordering_1',['king_ordering',['../namespaceDoFRenumbering_1_1boost.html#a76fd1dc3212aeeca4294c358248e46d5',1,'DoFRenumbering::boost']]],
   ['kinsol_2',['KINSOL',['../classSUNDIALS_1_1KINSOL.html#acf2dfd38812321750b174be317050f37',1,'SUNDIALS::KINSOL::KINSOL(const AdditionalData &amp;data=AdditionalData())'],['../classSUNDIALS_1_1KINSOL.html#a79e61e84af403eb5e5429d053f579822',1,'SUNDIALS::KINSOL::KINSOL(const AdditionalData &amp;data, const MPI_Comm mpi_comm)']]],
-  ['kovasznay_3',['Kovasznay',['../classFunctions_1_1Kovasznay.html#a082166be0e076803fed98a61450e05a5',1,'Functions::Kovasznay']]]
+  ['kovasznay_3',['Kovasznay',['../classFunctions_1_1Kovasznay.html#a082166be0e076803fed98a61450e05a5',1,'Functions::Kovasznay']]],
+  ['kronecker_5fproduct_4',['kronecker_product',['../classFullMatrix.html#a1a27e8918714131096c51999752d31db',1,'FullMatrix']]]
 ];
