@@ -1,19 +1,19 @@
 var indexSectionsWithContent =
 {
-  0: "123456789:_abcdefghijklmnopqrstuvwxyz~",
+  0: "0123456789:_abcdefghijklmnopqrstuvwxyz~",
   1: "abcdefghijklmnopqrstuvwxz",
   2: "abcdefghilmnoprstuvw",
   3: "123456789abcdefghijklmnopqrstuvw",
   4: "abcdefghijklmnopqrstuvwxz~",
   5: "_abcdefghijklmnopqrstuvwxyz",
-  6: "abcdefghijklmnopqrstvwz",
-  7: "abcdefghilmnoprstuvw",
+  6: "abcdefghijklmnopqrstuvw",
+  7: "abcdefghilmnopqrstuvw",
   8: "abcdefghijklmnopqrstuvwxz",
   9: ":abcdfgilmnoprstuv",
   10: "abdefhimpst",
-  11: "abcdefghilmnopqstuv",
-  12: "bcdgtw",
-  13: "c"
+  11: "abcdefghilmnopqrstuvw",
+  12: "0123456789:abcdefghijklmnopqrstuvwxy",
+  13: "i"
 };
 
 var indexSectionNames =
